// Deprecated: Please note, this package has been deprecated. A replacement package is available [github.com/Azure/azure-sdk-for-go/sdk/resourcemanager/addons/armaddons](https://pkg.go.dev/github.com/Azure/azure-sdk-for-go/sdk/resourcemanager/addons/armaddons). We strongly encourage you to upgrade to continue receiving updates. See [Migration Guide](https://aka.ms/azsdk/golang/t2/migration) for guidance on upgrading. Refer to our [deprecation policy](https://azure.github.io/azure-sdk/policies_support.html) for more details.
package addonsapi

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.
//
// Code generated by Microsoft (R) AutoRest Code Generator.
// Changes may cause incorrect behavior and will be lost if the code is regenerated.

import (
	"context"
	"github.com/Azure/azure-sdk-for-go/services/preview/addons/mgmt/2017-05-15/addons"
)

// OperationsClientAPI contains the set of methods on the OperationsClient type.
type OperationsClientAPI interface {
	List(ctx context.Context) (result addons.ListOperationsDefinition, err error)
}

var _ OperationsClientAPI = (*addons.OperationsClient)(nil)

// SupportPlanTypesClientAPI contains the set of methods on the SupportPlanTypesClient type.
type SupportPlanTypesClientAPI interface {
	CreateOrUpdate(ctx context.Context, providerName string, planTypeName addons.PlanTypeName) (result addons.SupportPlanTypesCreateOrUpdateFuture, err error)
	Delete(ctx context.Context, providerName string, planTypeName addons.PlanTypeName) (result addons.SupportPlanTypesDeleteFuture, err error)
	Get(ctx context.Context, providerName string, planTypeName addons.PlanTypeName) (result addons.CanonicalSupportPlanResponseEnvelope, err error)
}

var _ SupportPlanTypesClientAPI = (*addons.SupportPlanTypesClient)(nil)

// CanonicalSupportPlanTypesClientAPI contains the set of methods on the CanonicalSupportPlanTypesClient type.
type CanonicalSupportPlanTypesClientAPI interface {
	Get(ctx context.Context, providerName string) (result addons.ListCanonicalSupportPlanStatusItem, err error)
}

var _ CanonicalSupportPlanTypesClientAPI = (*addons.CanonicalSupportPlanTypesClient)(nil)
