//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package storsimpleapi

import original "github.com/Azure/azure-sdk-for-go/services/storsimple1200series/mgmt/2016-10-01/storsimple/storsimpleapi"

type AccessControlRecordsClientAPI = original.AccessControlRecordsClientAPI
type AlertsClientAPI = original.AlertsClientAPI
type AvailableProviderOperationsClientAPI = original.AvailableProviderOperationsClientAPI
type BackupScheduleGroupsClientAPI = original.BackupScheduleGroupsClientAPI
type BackupsClientAPI = original.BackupsClientAPI
type ChapSettingsClientAPI = original.ChapSettingsClientAPI
type DevicesClientAPI = original.DevicesClientAPI
type FileServersClientAPI = original.FileServersClientAPI
type FileSharesClientAPI = original.FileSharesClientAPI
type IscsiDisksClientAPI = original.IscsiDisksClientAPI
type IscsiServersClientAPI = original.IscsiServersClientAPI
type JobsClientAPI = original.JobsClientAPI
type ManagersClientAPI = original.ManagersClientAPI
type StorageAccountCredentialsClientAPI = original.StorageAccountCredentialsClientAPI
type StorageDomainsClientAPI = original.StorageDomainsClientAPI
