package managedvirtualnetworkapi

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.
//
// Code generated by Microsoft (R) AutoRest Code Generator.
// Changes may cause incorrect behavior and will be lost if the code is regenerated.

import (
	"context"
	"github.com/Azure/azure-sdk-for-go/services/preview/synapse/2019-06-01-preview/managedvirtualnetwork"
	"github.com/Azure/go-autorest/autorest"
)

// ManagedPrivateEndpointsClientAPI contains the set of methods on the ManagedPrivateEndpointsClient type.
type ManagedPrivateEndpointsClientAPI interface {
	Create(ctx context.Context, managedVirtualNetworkName string, managedPrivateEndpointName string, managedPrivateEndpoint managedvirtualnetwork.ManagedPrivateEndpoint) (result managedvirtualnetwork.ManagedPrivateEndpoint, err error)
	Delete(ctx context.Context, managedVirtualNetworkName string, managedPrivateEndpointName string) (result autorest.Response, err error)
	Get(ctx context.Context, managedVirtualNetworkName string, managedPrivateEndpointName string) (result managedvirtualnetwork.ManagedPrivateEndpoint, err error)
	List(ctx context.Context, managedVirtualNetworkName string) (result managedvirtualnetwork.ManagedPrivateEndpointListResponsePage, err error)
	ListComplete(ctx context.Context, managedVirtualNetworkName string) (result managedvirtualnetwork.ManagedPrivateEndpointListResponseIterator, err error)
}

var _ ManagedPrivateEndpointsClientAPI = (*managedvirtualnetwork.ManagedPrivateEndpointsClient)(nil)
