//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package datashareapi

import original "github.com/Azure/azure-sdk-for-go/services/datashare/mgmt/2019-11-01/datashare/datashareapi"

type AccountsClientAPI = original.AccountsClientAPI
type ConsumerInvitationsClientAPI = original.ConsumerInvitationsClientAPI
type ConsumerSourceDataSetsClientAPI = original.ConsumerSourceDataSetsClientAPI
type DataSetMappingsClientAPI = original.DataSetMappingsClientAPI
type DataSetsClientAPI = original.DataSetsClientAPI
type InvitationsClientAPI = original.InvitationsClientAPI
type OperationsClientAPI = original.OperationsClientAPI
type ProviderShareSubscriptionsClientAPI = original.ProviderShareSubscriptionsClientAPI
type ShareSubscriptionsClientAPI = original.ShareSubscriptionsClientAPI
type SharesClientAPI = original.SharesClientAPI
type SynchronizationSettingsClientAPI = original.SynchronizationSettingsClientAPI
type TriggersClientAPI = original.TriggersClientAPI
