//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package authorizationapi

import original "github.com/Azure/azure-sdk-for-go/services/authorization/mgmt/2015-07-01/authorization/authorizationapi"

type ClassicAdministratorsClientAPI = original.ClassicAdministratorsClientAPI
type GlobalAdministratorClientAPI = original.GlobalAdministratorClientAPI
type PermissionsClientAPI = original.PermissionsClientAPI
type ProviderOperationsMetadataClientAPI = original.ProviderOperationsMetadataClientAPI
type RoleAssignmentsClientAPI = original.RoleAssignmentsClientAPI
type RoleDefinitionsClientAPI = original.RoleDefinitionsClientAPI
