//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package supportapi

import original "github.com/Azure/azure-sdk-for-go/services/support/mgmt/2020-04-01/support/supportapi"

type CommunicationsClientAPI = original.CommunicationsClientAPI
type OperationsClientAPI = original.OperationsClientAPI
type ProblemClassificationsClientAPI = original.ProblemClassificationsClientAPI
type ServicesClientAPI = original.ServicesClientAPI
type TicketsClientAPI = original.TicketsClientAPI
