//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package automation

import (
	"context"

	original "github.com/Azure/azure-sdk-for-go/services/preview/automation/mgmt/2021-06-22-preview/automation"
)

const (
	DefaultBaseURI = original.DefaultBaseURI
)

type AccountState = original.AccountState

const (
	AccountStateOk          AccountState = original.AccountStateOk
	AccountStateSuspended   AccountState = original.AccountStateSuspended
	AccountStateUnavailable AccountState = original.AccountStateUnavailable
)

type AgentRegistrationKeyName = original.AgentRegistrationKeyName

const (
	AgentRegistrationKeyNamePrimary   AgentRegistrationKeyName = original.AgentRegistrationKeyNamePrimary
	AgentRegistrationKeyNameSecondary AgentRegistrationKeyName = original.AgentRegistrationKeyNameSecondary
)

type ContentSourceType = original.ContentSourceType

const (
	ContentSourceTypeEmbeddedContent ContentSourceType = original.ContentSourceTypeEmbeddedContent
	ContentSourceTypeURI             ContentSourceType = original.ContentSourceTypeURI
)

type CountType = original.CountType

const (
	CountTypeNodeconfiguration CountType = original.CountTypeNodeconfiguration
	CountTypeStatus            CountType = original.CountTypeStatus
)

type CreatedByType = original.CreatedByType

const (
	CreatedByTypeApplication     CreatedByType = original.CreatedByTypeApplication
	CreatedByTypeKey             CreatedByType = original.CreatedByTypeKey
	CreatedByTypeManagedIdentity CreatedByType = original.CreatedByTypeManagedIdentity
	CreatedByTypeUser            CreatedByType = original.CreatedByTypeUser
)

type DscConfigurationProvisioningState = original.DscConfigurationProvisioningState

const (
	DscConfigurationProvisioningStateSucceeded DscConfigurationProvisioningState = original.DscConfigurationProvisioningStateSucceeded
)

type DscConfigurationState = original.DscConfigurationState

const (
	DscConfigurationStateEdit      DscConfigurationState = original.DscConfigurationStateEdit
	DscConfigurationStateNew       DscConfigurationState = original.DscConfigurationStateNew
	DscConfigurationStatePublished DscConfigurationState = original.DscConfigurationStatePublished
)

type EncryptionKeySourceType = original.EncryptionKeySourceType

const (
	EncryptionKeySourceTypeMicrosoftAutomation EncryptionKeySourceType = original.EncryptionKeySourceTypeMicrosoftAutomation
	EncryptionKeySourceTypeMicrosoftKeyvault   EncryptionKeySourceType = original.EncryptionKeySourceTypeMicrosoftKeyvault
)

type GraphRunbookType = original.GraphRunbookType

const (
	GraphRunbookTypeGraphPowerShell         GraphRunbookType = original.GraphRunbookTypeGraphPowerShell
	GraphRunbookTypeGraphPowerShellWorkflow GraphRunbookType = original.GraphRunbookTypeGraphPowerShellWorkflow
)

type GroupTypeEnum = original.GroupTypeEnum

const (
	GroupTypeEnumSystem GroupTypeEnum = original.GroupTypeEnumSystem
	GroupTypeEnumUser   GroupTypeEnum = original.GroupTypeEnumUser
)

type HTTPStatusCode = original.HTTPStatusCode

const (
	HTTPStatusCodeAccepted                     HTTPStatusCode = original.HTTPStatusCodeAccepted
	HTTPStatusCodeAmbiguous                    HTTPStatusCode = original.HTTPStatusCodeAmbiguous
	HTTPStatusCodeBadGateway                   HTTPStatusCode = original.HTTPStatusCodeBadGateway
	HTTPStatusCodeBadRequest                   HTTPStatusCode = original.HTTPStatusCodeBadRequest
	HTTPStatusCodeConflict                     HTTPStatusCode = original.HTTPStatusCodeConflict
	HTTPStatusCodeContinue                     HTTPStatusCode = original.HTTPStatusCodeContinue
	HTTPStatusCodeCreated                      HTTPStatusCode = original.HTTPStatusCodeCreated
	HTTPStatusCodeExpectationFailed            HTTPStatusCode = original.HTTPStatusCodeExpectationFailed
	HTTPStatusCodeForbidden                    HTTPStatusCode = original.HTTPStatusCodeForbidden
	HTTPStatusCodeFound                        HTTPStatusCode = original.HTTPStatusCodeFound
	HTTPStatusCodeGatewayTimeout               HTTPStatusCode = original.HTTPStatusCodeGatewayTimeout
	HTTPStatusCodeGone                         HTTPStatusCode = original.HTTPStatusCodeGone
	HTTPStatusCodeHTTPVersionNotSupported      HTTPStatusCode = original.HTTPStatusCodeHTTPVersionNotSupported
	HTTPStatusCodeInternalServerError          HTTPStatusCode = original.HTTPStatusCodeInternalServerError
	HTTPStatusCodeLengthRequired               HTTPStatusCode = original.HTTPStatusCodeLengthRequired
	HTTPStatusCodeMethodNotAllowed             HTTPStatusCode = original.HTTPStatusCodeMethodNotAllowed
	HTTPStatusCodeMoved                        HTTPStatusCode = original.HTTPStatusCodeMoved
	HTTPStatusCodeMovedPermanently             HTTPStatusCode = original.HTTPStatusCodeMovedPermanently
	HTTPStatusCodeMultipleChoices              HTTPStatusCode = original.HTTPStatusCodeMultipleChoices
	HTTPStatusCodeNoContent                    HTTPStatusCode = original.HTTPStatusCodeNoContent
	HTTPStatusCodeNonAuthoritativeInformation  HTTPStatusCode = original.HTTPStatusCodeNonAuthoritativeInformation
	HTTPStatusCodeNotAcceptable                HTTPStatusCode = original.HTTPStatusCodeNotAcceptable
	HTTPStatusCodeNotFound                     HTTPStatusCode = original.HTTPStatusCodeNotFound
	HTTPStatusCodeNotImplemented               HTTPStatusCode = original.HTTPStatusCodeNotImplemented
	HTTPStatusCodeNotModified                  HTTPStatusCode = original.HTTPStatusCodeNotModified
	HTTPStatusCodeOK                           HTTPStatusCode = original.HTTPStatusCodeOK
	HTTPStatusCodePartialContent               HTTPStatusCode = original.HTTPStatusCodePartialContent
	HTTPStatusCodePaymentRequired              HTTPStatusCode = original.HTTPStatusCodePaymentRequired
	HTTPStatusCodePreconditionFailed           HTTPStatusCode = original.HTTPStatusCodePreconditionFailed
	HTTPStatusCodeProxyAuthenticationRequired  HTTPStatusCode = original.HTTPStatusCodeProxyAuthenticationRequired
	HTTPStatusCodeRedirect                     HTTPStatusCode = original.HTTPStatusCodeRedirect
	HTTPStatusCodeRedirectKeepVerb             HTTPStatusCode = original.HTTPStatusCodeRedirectKeepVerb
	HTTPStatusCodeRedirectMethod               HTTPStatusCode = original.HTTPStatusCodeRedirectMethod
	HTTPStatusCodeRequestedRangeNotSatisfiable HTTPStatusCode = original.HTTPStatusCodeRequestedRangeNotSatisfiable
	HTTPStatusCodeRequestEntityTooLarge        HTTPStatusCode = original.HTTPStatusCodeRequestEntityTooLarge
	HTTPStatusCodeRequestTimeout               HTTPStatusCode = original.HTTPStatusCodeRequestTimeout
	HTTPStatusCodeRequestURITooLong            HTTPStatusCode = original.HTTPStatusCodeRequestURITooLong
	HTTPStatusCodeResetContent                 HTTPStatusCode = original.HTTPStatusCodeResetContent
	HTTPStatusCodeSeeOther                     HTTPStatusCode = original.HTTPStatusCodeSeeOther
	HTTPStatusCodeServiceUnavailable           HTTPStatusCode = original.HTTPStatusCodeServiceUnavailable
	HTTPStatusCodeSwitchingProtocols           HTTPStatusCode = original.HTTPStatusCodeSwitchingProtocols
	HTTPStatusCodeTemporaryRedirect            HTTPStatusCode = original.HTTPStatusCodeTemporaryRedirect
	HTTPStatusCodeUnauthorized                 HTTPStatusCode = original.HTTPStatusCodeUnauthorized
	HTTPStatusCodeUnsupportedMediaType         HTTPStatusCode = original.HTTPStatusCodeUnsupportedMediaType
	HTTPStatusCodeUnused                       HTTPStatusCode = original.HTTPStatusCodeUnused
	HTTPStatusCodeUpgradeRequired              HTTPStatusCode = original.HTTPStatusCodeUpgradeRequired
	HTTPStatusCodeUseProxy                     HTTPStatusCode = original.HTTPStatusCodeUseProxy
)

type JobProvisioningState = original.JobProvisioningState

const (
	JobProvisioningStateFailed     JobProvisioningState = original.JobProvisioningStateFailed
	JobProvisioningStateProcessing JobProvisioningState = original.JobProvisioningStateProcessing
	JobProvisioningStateSucceeded  JobProvisioningState = original.JobProvisioningStateSucceeded
	JobProvisioningStateSuspended  JobProvisioningState = original.JobProvisioningStateSuspended
)

type JobStatus = original.JobStatus

const (
	JobStatusActivating   JobStatus = original.JobStatusActivating
	JobStatusBlocked      JobStatus = original.JobStatusBlocked
	JobStatusCompleted    JobStatus = original.JobStatusCompleted
	JobStatusDisconnected JobStatus = original.JobStatusDisconnected
	JobStatusFailed       JobStatus = original.JobStatusFailed
	JobStatusNew          JobStatus = original.JobStatusNew
	JobStatusRemoving     JobStatus = original.JobStatusRemoving
	JobStatusResuming     JobStatus = original.JobStatusResuming
	JobStatusRunning      JobStatus = original.JobStatusRunning
	JobStatusStopped      JobStatus = original.JobStatusStopped
	JobStatusStopping     JobStatus = original.JobStatusStopping
	JobStatusSuspended    JobStatus = original.JobStatusSuspended
	JobStatusSuspending   JobStatus = original.JobStatusSuspending
)

type JobStreamType = original.JobStreamType

const (
	JobStreamTypeAny      JobStreamType = original.JobStreamTypeAny
	JobStreamTypeDebug    JobStreamType = original.JobStreamTypeDebug
	JobStreamTypeError    JobStreamType = original.JobStreamTypeError
	JobStreamTypeOutput   JobStreamType = original.JobStreamTypeOutput
	JobStreamTypeProgress JobStreamType = original.JobStreamTypeProgress
	JobStreamTypeVerbose  JobStreamType = original.JobStreamTypeVerbose
	JobStreamTypeWarning  JobStreamType = original.JobStreamTypeWarning
)

type KeyName = original.KeyName

const (
	KeyNamePrimary   KeyName = original.KeyNamePrimary
	KeyNameSecondary KeyName = original.KeyNameSecondary
)

type KeyPermissions = original.KeyPermissions

const (
	KeyPermissionsFull KeyPermissions = original.KeyPermissionsFull
	KeyPermissionsRead KeyPermissions = original.KeyPermissionsRead
)

type LinuxUpdateClasses = original.LinuxUpdateClasses

const (
	LinuxUpdateClassesCritical     LinuxUpdateClasses = original.LinuxUpdateClassesCritical
	LinuxUpdateClassesOther        LinuxUpdateClasses = original.LinuxUpdateClassesOther
	LinuxUpdateClassesSecurity     LinuxUpdateClasses = original.LinuxUpdateClassesSecurity
	LinuxUpdateClassesUnclassified LinuxUpdateClasses = original.LinuxUpdateClassesUnclassified
)

type ModuleProvisioningState = original.ModuleProvisioningState

const (
	ModuleProvisioningStateActivitiesStored            ModuleProvisioningState = original.ModuleProvisioningStateActivitiesStored
	ModuleProvisioningStateCancelled                   ModuleProvisioningState = original.ModuleProvisioningStateCancelled
	ModuleProvisioningStateConnectionTypeImported      ModuleProvisioningState = original.ModuleProvisioningStateConnectionTypeImported
	ModuleProvisioningStateContentDownloaded           ModuleProvisioningState = original.ModuleProvisioningStateContentDownloaded
	ModuleProvisioningStateContentRetrieved            ModuleProvisioningState = original.ModuleProvisioningStateContentRetrieved
	ModuleProvisioningStateContentStored               ModuleProvisioningState = original.ModuleProvisioningStateContentStored
	ModuleProvisioningStateContentValidated            ModuleProvisioningState = original.ModuleProvisioningStateContentValidated
	ModuleProvisioningStateCreated                     ModuleProvisioningState = original.ModuleProvisioningStateCreated
	ModuleProvisioningStateCreating                    ModuleProvisioningState = original.ModuleProvisioningStateCreating
	ModuleProvisioningStateFailed                      ModuleProvisioningState = original.ModuleProvisioningStateFailed
	ModuleProvisioningStateModuleDataStored            ModuleProvisioningState = original.ModuleProvisioningStateModuleDataStored
	ModuleProvisioningStateModuleImportRunbookComplete ModuleProvisioningState = original.ModuleProvisioningStateModuleImportRunbookComplete
	ModuleProvisioningStateRunningImportModuleRunbook  ModuleProvisioningState = original.ModuleProvisioningStateRunningImportModuleRunbook
	ModuleProvisioningStateStartingImportModuleRunbook ModuleProvisioningState = original.ModuleProvisioningStateStartingImportModuleRunbook
	ModuleProvisioningStateSucceeded                   ModuleProvisioningState = original.ModuleProvisioningStateSucceeded
	ModuleProvisioningStateUpdating                    ModuleProvisioningState = original.ModuleProvisioningStateUpdating
)

type OperatingSystemType = original.OperatingSystemType

const (
	OperatingSystemTypeLinux   OperatingSystemType = original.OperatingSystemTypeLinux
	OperatingSystemTypeWindows OperatingSystemType = original.OperatingSystemTypeWindows
)

type ProvisioningState = original.ProvisioningState

const (
	ProvisioningStateCompleted ProvisioningState = original.ProvisioningStateCompleted
	ProvisioningStateFailed    ProvisioningState = original.ProvisioningStateFailed
	ProvisioningStateRunning   ProvisioningState = original.ProvisioningStateRunning
)

type ResourceIdentityType = original.ResourceIdentityType

const (
	ResourceIdentityTypeNone                       ResourceIdentityType = original.ResourceIdentityTypeNone
	ResourceIdentityTypeSystemAssigned             ResourceIdentityType = original.ResourceIdentityTypeSystemAssigned
	ResourceIdentityTypeSystemAssignedUserAssigned ResourceIdentityType = original.ResourceIdentityTypeSystemAssignedUserAssigned
	ResourceIdentityTypeUserAssigned               ResourceIdentityType = original.ResourceIdentityTypeUserAssigned
)

type RunbookProvisioningState = original.RunbookProvisioningState

const (
	RunbookProvisioningStateSucceeded RunbookProvisioningState = original.RunbookProvisioningStateSucceeded
)

type RunbookState = original.RunbookState

const (
	RunbookStateEdit      RunbookState = original.RunbookStateEdit
	RunbookStateNew       RunbookState = original.RunbookStateNew
	RunbookStatePublished RunbookState = original.RunbookStatePublished
)

type RunbookTypeEnum = original.RunbookTypeEnum

const (
	RunbookTypeEnumGraph                   RunbookTypeEnum = original.RunbookTypeEnumGraph
	RunbookTypeEnumGraphPowerShell         RunbookTypeEnum = original.RunbookTypeEnumGraphPowerShell
	RunbookTypeEnumGraphPowerShellWorkflow RunbookTypeEnum = original.RunbookTypeEnumGraphPowerShellWorkflow
	RunbookTypeEnumPowerShell              RunbookTypeEnum = original.RunbookTypeEnumPowerShell
	RunbookTypeEnumPowerShellWorkflow      RunbookTypeEnum = original.RunbookTypeEnumPowerShellWorkflow
	RunbookTypeEnumScript                  RunbookTypeEnum = original.RunbookTypeEnumScript
)

type ScheduleDay = original.ScheduleDay

const (
	ScheduleDayFriday    ScheduleDay = original.ScheduleDayFriday
	ScheduleDayMonday    ScheduleDay = original.ScheduleDayMonday
	ScheduleDaySaturday  ScheduleDay = original.ScheduleDaySaturday
	ScheduleDaySunday    ScheduleDay = original.ScheduleDaySunday
	ScheduleDayThursday  ScheduleDay = original.ScheduleDayThursday
	ScheduleDayTuesday   ScheduleDay = original.ScheduleDayTuesday
	ScheduleDayWednesday ScheduleDay = original.ScheduleDayWednesday
)

type ScheduleFrequency = original.ScheduleFrequency

const (
	ScheduleFrequencyDay     ScheduleFrequency = original.ScheduleFrequencyDay
	ScheduleFrequencyHour    ScheduleFrequency = original.ScheduleFrequencyHour
	ScheduleFrequencyMinute  ScheduleFrequency = original.ScheduleFrequencyMinute
	ScheduleFrequencyMonth   ScheduleFrequency = original.ScheduleFrequencyMonth
	ScheduleFrequencyOneTime ScheduleFrequency = original.ScheduleFrequencyOneTime
	ScheduleFrequencyWeek    ScheduleFrequency = original.ScheduleFrequencyWeek
)

type SkuNameEnum = original.SkuNameEnum

const (
	SkuNameEnumBasic SkuNameEnum = original.SkuNameEnumBasic
	SkuNameEnumFree  SkuNameEnum = original.SkuNameEnumFree
)

type SourceType = original.SourceType

const (
	SourceTypeGitHub  SourceType = original.SourceTypeGitHub
	SourceTypeVsoGit  SourceType = original.SourceTypeVsoGit
	SourceTypeVsoTfvc SourceType = original.SourceTypeVsoTfvc
)

type StreamType = original.StreamType

const (
	StreamTypeError  StreamType = original.StreamTypeError
	StreamTypeOutput StreamType = original.StreamTypeOutput
)

type SyncType = original.SyncType

const (
	SyncTypeFullSync    SyncType = original.SyncTypeFullSync
	SyncTypePartialSync SyncType = original.SyncTypePartialSync
)

type TagOperators = original.TagOperators

const (
	TagOperatorsAll TagOperators = original.TagOperatorsAll
	TagOperatorsAny TagOperators = original.TagOperatorsAny
)

type TokenType = original.TokenType

const (
	TokenTypeOauth               TokenType = original.TokenTypeOauth
	TokenTypePersonalAccessToken TokenType = original.TokenTypePersonalAccessToken
)

type WindowsUpdateClasses = original.WindowsUpdateClasses

const (
	WindowsUpdateClassesCritical     WindowsUpdateClasses = original.WindowsUpdateClassesCritical
	WindowsUpdateClassesDefinition   WindowsUpdateClasses = original.WindowsUpdateClassesDefinition
	WindowsUpdateClassesFeaturePack  WindowsUpdateClasses = original.WindowsUpdateClassesFeaturePack
	WindowsUpdateClassesSecurity     WindowsUpdateClasses = original.WindowsUpdateClassesSecurity
	WindowsUpdateClassesServicePack  WindowsUpdateClasses = original.WindowsUpdateClassesServicePack
	WindowsUpdateClassesTools        WindowsUpdateClasses = original.WindowsUpdateClassesTools
	WindowsUpdateClassesUnclassified WindowsUpdateClasses = original.WindowsUpdateClassesUnclassified
	WindowsUpdateClassesUpdateRollup WindowsUpdateClasses = original.WindowsUpdateClassesUpdateRollup
	WindowsUpdateClassesUpdates      WindowsUpdateClasses = original.WindowsUpdateClassesUpdates
)

type WorkerType = original.WorkerType

const (
	WorkerTypeHybridV1 WorkerType = original.WorkerTypeHybridV1
	WorkerTypeHybridV2 WorkerType = original.WorkerTypeHybridV2
)

type Account = original.Account
type AccountClient = original.AccountClient
type AccountCreateOrUpdateParameters = original.AccountCreateOrUpdateParameters
type AccountCreateOrUpdateProperties = original.AccountCreateOrUpdateProperties
type AccountListResult = original.AccountListResult
type AccountListResultIterator = original.AccountListResultIterator
type AccountListResultPage = original.AccountListResultPage
type AccountProperties = original.AccountProperties
type AccountUpdateParameters = original.AccountUpdateParameters
type AccountUpdateProperties = original.AccountUpdateProperties
type Activity = original.Activity
type ActivityClient = original.ActivityClient
type ActivityListResult = original.ActivityListResult
type ActivityListResultIterator = original.ActivityListResultIterator
type ActivityListResultPage = original.ActivityListResultPage
type ActivityOutputType = original.ActivityOutputType
type ActivityParameter = original.ActivityParameter
type ActivityParameterSet = original.ActivityParameterSet
type ActivityParameterValidationSet = original.ActivityParameterValidationSet
type ActivityProperties = original.ActivityProperties
type AdvancedSchedule = original.AdvancedSchedule
type AdvancedScheduleMonthlyOccurrence = original.AdvancedScheduleMonthlyOccurrence
type AgentRegistration = original.AgentRegistration
type AgentRegistrationInformationClient = original.AgentRegistrationInformationClient
type AgentRegistrationKeys = original.AgentRegistrationKeys
type AgentRegistrationRegenerateKeyParameter = original.AgentRegistrationRegenerateKeyParameter
type AzureQueryProperties = original.AzureQueryProperties
type BaseClient = original.BaseClient
type Certificate = original.Certificate
type CertificateClient = original.CertificateClient
type CertificateCreateOrUpdateParameters = original.CertificateCreateOrUpdateParameters
type CertificateCreateOrUpdateProperties = original.CertificateCreateOrUpdateProperties
type CertificateListResult = original.CertificateListResult
type CertificateListResultIterator = original.CertificateListResultIterator
type CertificateListResultPage = original.CertificateListResultPage
type CertificateProperties = original.CertificateProperties
type CertificateUpdateParameters = original.CertificateUpdateParameters
type CertificateUpdateProperties = original.CertificateUpdateProperties
type Connection = original.Connection
type ConnectionClient = original.ConnectionClient
type ConnectionCreateOrUpdateParameters = original.ConnectionCreateOrUpdateParameters
type ConnectionCreateOrUpdateProperties = original.ConnectionCreateOrUpdateProperties
type ConnectionListResult = original.ConnectionListResult
type ConnectionListResultIterator = original.ConnectionListResultIterator
type ConnectionListResultPage = original.ConnectionListResultPage
type ConnectionProperties = original.ConnectionProperties
type ConnectionType = original.ConnectionType
type ConnectionTypeAssociationProperty = original.ConnectionTypeAssociationProperty
type ConnectionTypeClient = original.ConnectionTypeClient
type ConnectionTypeCreateOrUpdateParameters = original.ConnectionTypeCreateOrUpdateParameters
type ConnectionTypeCreateOrUpdateProperties = original.ConnectionTypeCreateOrUpdateProperties
type ConnectionTypeListResult = original.ConnectionTypeListResult
type ConnectionTypeListResultIterator = original.ConnectionTypeListResultIterator
type ConnectionTypeListResultPage = original.ConnectionTypeListResultPage
type ConnectionTypeProperties = original.ConnectionTypeProperties
type ConnectionUpdateParameters = original.ConnectionUpdateParameters
type ConnectionUpdateProperties = original.ConnectionUpdateProperties
type ContentHash = original.ContentHash
type ContentLink = original.ContentLink
type ContentSource = original.ContentSource
type Credential = original.Credential
type CredentialClient = original.CredentialClient
type CredentialCreateOrUpdateParameters = original.CredentialCreateOrUpdateParameters
type CredentialCreateOrUpdateProperties = original.CredentialCreateOrUpdateProperties
type CredentialListResult = original.CredentialListResult
type CredentialListResultIterator = original.CredentialListResultIterator
type CredentialListResultPage = original.CredentialListResultPage
type CredentialProperties = original.CredentialProperties
type CredentialUpdateParameters = original.CredentialUpdateParameters
type CredentialUpdateProperties = original.CredentialUpdateProperties
type DscCompilationJob = original.DscCompilationJob
type DscCompilationJobClient = original.DscCompilationJobClient
type DscCompilationJobCreateFuture = original.DscCompilationJobCreateFuture
type DscCompilationJobCreateParameters = original.DscCompilationJobCreateParameters
type DscCompilationJobCreateProperties = original.DscCompilationJobCreateProperties
type DscCompilationJobListResult = original.DscCompilationJobListResult
type DscCompilationJobListResultIterator = original.DscCompilationJobListResultIterator
type DscCompilationJobListResultPage = original.DscCompilationJobListResultPage
type DscCompilationJobProperties = original.DscCompilationJobProperties
type DscCompilationJobStreamClient = original.DscCompilationJobStreamClient
type DscConfiguration = original.DscConfiguration
type DscConfigurationAssociationProperty = original.DscConfigurationAssociationProperty
type DscConfigurationClient = original.DscConfigurationClient
type DscConfigurationCreateOrUpdateParameters = original.DscConfigurationCreateOrUpdateParameters
type DscConfigurationCreateOrUpdateProperties = original.DscConfigurationCreateOrUpdateProperties
type DscConfigurationListResult = original.DscConfigurationListResult
type DscConfigurationListResultIterator = original.DscConfigurationListResultIterator
type DscConfigurationListResultPage = original.DscConfigurationListResultPage
type DscConfigurationParameter = original.DscConfigurationParameter
type DscConfigurationProperties = original.DscConfigurationProperties
type DscConfigurationUpdateParameters = original.DscConfigurationUpdateParameters
type DscMetaConfiguration = original.DscMetaConfiguration
type DscNode = original.DscNode
type DscNodeClient = original.DscNodeClient
type DscNodeConfiguration = original.DscNodeConfiguration
type DscNodeConfigurationAssociationProperty = original.DscNodeConfigurationAssociationProperty
type DscNodeConfigurationClient = original.DscNodeConfigurationClient
type DscNodeConfigurationCreateOrUpdateFuture = original.DscNodeConfigurationCreateOrUpdateFuture
type DscNodeConfigurationCreateOrUpdateParameters = original.DscNodeConfigurationCreateOrUpdateParameters
type DscNodeConfigurationCreateOrUpdateParametersProperties = original.DscNodeConfigurationCreateOrUpdateParametersProperties
type DscNodeConfigurationListResult = original.DscNodeConfigurationListResult
type DscNodeConfigurationListResultIterator = original.DscNodeConfigurationListResultIterator
type DscNodeConfigurationListResultPage = original.DscNodeConfigurationListResultPage
type DscNodeConfigurationProperties = original.DscNodeConfigurationProperties
type DscNodeExtensionHandlerAssociationProperty = original.DscNodeExtensionHandlerAssociationProperty
type DscNodeListResult = original.DscNodeListResult
type DscNodeListResultIterator = original.DscNodeListResultIterator
type DscNodeListResultPage = original.DscNodeListResultPage
type DscNodeProperties = original.DscNodeProperties
type DscNodeReport = original.DscNodeReport
type DscNodeReportListResult = original.DscNodeReportListResult
type DscNodeReportListResultIterator = original.DscNodeReportListResultIterator
type DscNodeReportListResultPage = original.DscNodeReportListResultPage
type DscNodeUpdateParameters = original.DscNodeUpdateParameters
type DscNodeUpdateParametersProperties = original.DscNodeUpdateParametersProperties
type DscReportError = original.DscReportError
type DscReportResource = original.DscReportResource
type DscReportResourceNavigation = original.DscReportResourceNavigation
type EncryptionProperties = original.EncryptionProperties
type EncryptionPropertiesIdentity = original.EncryptionPropertiesIdentity
type ErrorResponse = original.ErrorResponse
type FieldDefinition = original.FieldDefinition
type FieldsClient = original.FieldsClient
type GraphicalRunbookContent = original.GraphicalRunbookContent
type HybridRunbookWorker = original.HybridRunbookWorker
type HybridRunbookWorkerCreateOrUpdateParameters = original.HybridRunbookWorkerCreateOrUpdateParameters
type HybridRunbookWorkerCreateParameters = original.HybridRunbookWorkerCreateParameters
type HybridRunbookWorkerGroup = original.HybridRunbookWorkerGroup
type HybridRunbookWorkerGroupClient = original.HybridRunbookWorkerGroupClient
type HybridRunbookWorkerGroupCreateOrUpdateParameters = original.HybridRunbookWorkerGroupCreateOrUpdateParameters
type HybridRunbookWorkerGroupUpdateParameters = original.HybridRunbookWorkerGroupUpdateParameters
type HybridRunbookWorkerGroupsListResult = original.HybridRunbookWorkerGroupsListResult
type HybridRunbookWorkerGroupsListResultIterator = original.HybridRunbookWorkerGroupsListResultIterator
type HybridRunbookWorkerGroupsListResultPage = original.HybridRunbookWorkerGroupsListResultPage
type HybridRunbookWorkerLegacy = original.HybridRunbookWorkerLegacy
type HybridRunbookWorkerMoveParameters = original.HybridRunbookWorkerMoveParameters
type HybridRunbookWorkerProperties = original.HybridRunbookWorkerProperties
type HybridRunbookWorkersClient = original.HybridRunbookWorkersClient
type HybridRunbookWorkersListResult = original.HybridRunbookWorkersListResult
type HybridRunbookWorkersListResultIterator = original.HybridRunbookWorkersListResultIterator
type HybridRunbookWorkersListResultPage = original.HybridRunbookWorkersListResultPage
type Identity = original.Identity
type IdentityUserAssignedIdentitiesValue = original.IdentityUserAssignedIdentitiesValue
type Job = original.Job
type JobClient = original.JobClient
type JobCollectionItem = original.JobCollectionItem
type JobCollectionItemProperties = original.JobCollectionItemProperties
type JobCreateParameters = original.JobCreateParameters
type JobCreateProperties = original.JobCreateProperties
type JobListResultV2 = original.JobListResultV2
type JobListResultV2Iterator = original.JobListResultV2Iterator
type JobListResultV2Page = original.JobListResultV2Page
type JobNavigation = original.JobNavigation
type JobProperties = original.JobProperties
type JobSchedule = original.JobSchedule
type JobScheduleClient = original.JobScheduleClient
type JobScheduleCreateParameters = original.JobScheduleCreateParameters
type JobScheduleCreateProperties = original.JobScheduleCreateProperties
type JobScheduleListResult = original.JobScheduleListResult
type JobScheduleListResultIterator = original.JobScheduleListResultIterator
type JobScheduleListResultPage = original.JobScheduleListResultPage
type JobScheduleProperties = original.JobScheduleProperties
type JobStream = original.JobStream
type JobStreamClient = original.JobStreamClient
type JobStreamListResult = original.JobStreamListResult
type JobStreamListResultIterator = original.JobStreamListResultIterator
type JobStreamListResultPage = original.JobStreamListResultPage
type JobStreamProperties = original.JobStreamProperties
type Key = original.Key
type KeyListResult = original.KeyListResult
type KeyVaultProperties = original.KeyVaultProperties
type KeysClient = original.KeysClient
type LinkedWorkspace = original.LinkedWorkspace
type LinkedWorkspaceClient = original.LinkedWorkspaceClient
type LinuxProperties = original.LinuxProperties
type Module = original.Module
type ModuleClient = original.ModuleClient
type ModuleCreateOrUpdateParameters = original.ModuleCreateOrUpdateParameters
type ModuleCreateOrUpdateProperties = original.ModuleCreateOrUpdateProperties
type ModuleErrorInfo = original.ModuleErrorInfo
type ModuleListResult = original.ModuleListResult
type ModuleListResultIterator = original.ModuleListResultIterator
type ModuleListResultPage = original.ModuleListResultPage
type ModuleProperties = original.ModuleProperties
type ModuleUpdateParameters = original.ModuleUpdateParameters
type ModuleUpdateProperties = original.ModuleUpdateProperties
type NodeCount = original.NodeCount
type NodeCountInformationClient = original.NodeCountInformationClient
type NodeCountProperties = original.NodeCountProperties
type NodeCounts = original.NodeCounts
type NodeReportsClient = original.NodeReportsClient
type NonAzureQueryProperties = original.NonAzureQueryProperties
type ObjectDataTypesClient = original.ObjectDataTypesClient
type Operation = original.Operation
type OperationDisplay = original.OperationDisplay
type OperationListResult = original.OperationListResult
type OperationsClient = original.OperationsClient
type PrivateEndpointConnection = original.PrivateEndpointConnection
type PrivateEndpointConnectionListResult = original.PrivateEndpointConnectionListResult
type PrivateEndpointConnectionProperties = original.PrivateEndpointConnectionProperties
type PrivateEndpointConnectionsClient = original.PrivateEndpointConnectionsClient
type PrivateEndpointConnectionsCreateOrUpdateFuture = original.PrivateEndpointConnectionsCreateOrUpdateFuture
type PrivateEndpointConnectionsDeleteFuture = original.PrivateEndpointConnectionsDeleteFuture
type PrivateEndpointProperty = original.PrivateEndpointProperty
type PrivateLinkResource = original.PrivateLinkResource
type PrivateLinkResourceListResult = original.PrivateLinkResourceListResult
type PrivateLinkResourceProperties = original.PrivateLinkResourceProperties
type PrivateLinkResourcesClient = original.PrivateLinkResourcesClient
type PrivateLinkServiceConnectionStateProperty = original.PrivateLinkServiceConnectionStateProperty
type ProxyResource = original.ProxyResource
type Python2PackageClient = original.Python2PackageClient
type PythonPackageCreateParameters = original.PythonPackageCreateParameters
type PythonPackageCreateProperties = original.PythonPackageCreateProperties
type PythonPackageUpdateParameters = original.PythonPackageUpdateParameters
type RawGraphicalRunbookContent = original.RawGraphicalRunbookContent
type ReadCloser = original.ReadCloser
type Resource = original.Resource
type RunAsCredentialAssociationProperty = original.RunAsCredentialAssociationProperty
type Runbook = original.Runbook
type RunbookAssociationProperty = original.RunbookAssociationProperty
type RunbookClient = original.RunbookClient
type RunbookCreateOrUpdateDraftParameters = original.RunbookCreateOrUpdateDraftParameters
type RunbookCreateOrUpdateDraftProperties = original.RunbookCreateOrUpdateDraftProperties
type RunbookCreateOrUpdateParameters = original.RunbookCreateOrUpdateParameters
type RunbookCreateOrUpdateProperties = original.RunbookCreateOrUpdateProperties
type RunbookDraft = original.RunbookDraft
type RunbookDraftClient = original.RunbookDraftClient
type RunbookDraftReplaceContentFuture = original.RunbookDraftReplaceContentFuture
type RunbookDraftUndoEditResult = original.RunbookDraftUndoEditResult
type RunbookListResult = original.RunbookListResult
type RunbookListResultIterator = original.RunbookListResultIterator
type RunbookListResultPage = original.RunbookListResultPage
type RunbookParameter = original.RunbookParameter
type RunbookProperties = original.RunbookProperties
type RunbookPublishFuture = original.RunbookPublishFuture
type RunbookUpdateParameters = original.RunbookUpdateParameters
type RunbookUpdateProperties = original.RunbookUpdateProperties
type SUCScheduleProperties = original.SUCScheduleProperties
type Schedule = original.Schedule
type ScheduleAssociationProperty = original.ScheduleAssociationProperty
type ScheduleClient = original.ScheduleClient
type ScheduleCreateOrUpdateParameters = original.ScheduleCreateOrUpdateParameters
type ScheduleCreateOrUpdateProperties = original.ScheduleCreateOrUpdateProperties
type ScheduleListResult = original.ScheduleListResult
type ScheduleListResultIterator = original.ScheduleListResultIterator
type ScheduleListResultPage = original.ScheduleListResultPage
type ScheduleProperties = original.ScheduleProperties
type ScheduleUpdateParameters = original.ScheduleUpdateParameters
type ScheduleUpdateProperties = original.ScheduleUpdateProperties
type SetObject = original.SetObject
type Sku = original.Sku
type SoftwareUpdateConfiguration = original.SoftwareUpdateConfiguration
type SoftwareUpdateConfigurationCollectionItem = original.SoftwareUpdateConfigurationCollectionItem
type SoftwareUpdateConfigurationCollectionItemProperties = original.SoftwareUpdateConfigurationCollectionItemProperties
type SoftwareUpdateConfigurationListResult = original.SoftwareUpdateConfigurationListResult
type SoftwareUpdateConfigurationMachineRun = original.SoftwareUpdateConfigurationMachineRun
type SoftwareUpdateConfigurationMachineRunListResult = original.SoftwareUpdateConfigurationMachineRunListResult
type SoftwareUpdateConfigurationMachineRunsClient = original.SoftwareUpdateConfigurationMachineRunsClient
type SoftwareUpdateConfigurationProperties = original.SoftwareUpdateConfigurationProperties
type SoftwareUpdateConfigurationRun = original.SoftwareUpdateConfigurationRun
type SoftwareUpdateConfigurationRunListResult = original.SoftwareUpdateConfigurationRunListResult
type SoftwareUpdateConfigurationRunProperties = original.SoftwareUpdateConfigurationRunProperties
type SoftwareUpdateConfigurationRunTaskProperties = original.SoftwareUpdateConfigurationRunTaskProperties
type SoftwareUpdateConfigurationRunTasks = original.SoftwareUpdateConfigurationRunTasks
type SoftwareUpdateConfigurationRunsClient = original.SoftwareUpdateConfigurationRunsClient
type SoftwareUpdateConfigurationTasks = original.SoftwareUpdateConfigurationTasks
type SoftwareUpdateConfigurationsClient = original.SoftwareUpdateConfigurationsClient
type SourceControl = original.SourceControl
type SourceControlClient = original.SourceControlClient
type SourceControlCreateOrUpdateParameters = original.SourceControlCreateOrUpdateParameters
type SourceControlCreateOrUpdateProperties = original.SourceControlCreateOrUpdateProperties
type SourceControlListResult = original.SourceControlListResult
type SourceControlListResultIterator = original.SourceControlListResultIterator
type SourceControlListResultPage = original.SourceControlListResultPage
type SourceControlProperties = original.SourceControlProperties
type SourceControlSecurityTokenProperties = original.SourceControlSecurityTokenProperties
type SourceControlSyncJob = original.SourceControlSyncJob
type SourceControlSyncJobByID = original.SourceControlSyncJobByID
type SourceControlSyncJobByIDProperties = original.SourceControlSyncJobByIDProperties
type SourceControlSyncJobClient = original.SourceControlSyncJobClient
type SourceControlSyncJobCreateParameters = original.SourceControlSyncJobCreateParameters
type SourceControlSyncJobCreateProperties = original.SourceControlSyncJobCreateProperties
type SourceControlSyncJobListResult = original.SourceControlSyncJobListResult
type SourceControlSyncJobListResultIterator = original.SourceControlSyncJobListResultIterator
type SourceControlSyncJobListResultPage = original.SourceControlSyncJobListResultPage
type SourceControlSyncJobProperties = original.SourceControlSyncJobProperties
type SourceControlSyncJobStream = original.SourceControlSyncJobStream
type SourceControlSyncJobStreamByID = original.SourceControlSyncJobStreamByID
type SourceControlSyncJobStreamByIDProperties = original.SourceControlSyncJobStreamByIDProperties
type SourceControlSyncJobStreamProperties = original.SourceControlSyncJobStreamProperties
type SourceControlSyncJobStreamsClient = original.SourceControlSyncJobStreamsClient
type SourceControlSyncJobStreamsListBySyncJob = original.SourceControlSyncJobStreamsListBySyncJob
type SourceControlSyncJobStreamsListBySyncJobIterator = original.SourceControlSyncJobStreamsListBySyncJobIterator
type SourceControlSyncJobStreamsListBySyncJobPage = original.SourceControlSyncJobStreamsListBySyncJobPage
type SourceControlUpdateParameters = original.SourceControlUpdateParameters
type SourceControlUpdateProperties = original.SourceControlUpdateProperties
type Statistics = original.Statistics
type StatisticsClient = original.StatisticsClient
type StatisticsListResult = original.StatisticsListResult
type String = original.String
type SystemData = original.SystemData
type TagSettingsProperties = original.TagSettingsProperties
type TargetProperties = original.TargetProperties
type TaskProperties = original.TaskProperties
type TestJob = original.TestJob
type TestJobClient = original.TestJobClient
type TestJobCreateParameters = original.TestJobCreateParameters
type TestJobStreamsClient = original.TestJobStreamsClient
type TrackedResource = original.TrackedResource
type TypeField = original.TypeField
type TypeFieldListResult = original.TypeFieldListResult
type UpdateConfiguration = original.UpdateConfiguration
type UpdateConfigurationMachineRunProperties = original.UpdateConfigurationMachineRunProperties
type UpdateConfigurationNavigation = original.UpdateConfigurationNavigation
type Usage = original.Usage
type UsageCounterName = original.UsageCounterName
type UsageListResult = original.UsageListResult
type UsagesClient = original.UsagesClient
type Variable = original.Variable
type VariableClient = original.VariableClient
type VariableCreateOrUpdateParameters = original.VariableCreateOrUpdateParameters
type VariableCreateOrUpdateProperties = original.VariableCreateOrUpdateProperties
type VariableListResult = original.VariableListResult
type VariableListResultIterator = original.VariableListResultIterator
type VariableListResultPage = original.VariableListResultPage
type VariableProperties = original.VariableProperties
type VariableUpdateParameters = original.VariableUpdateParameters
type VariableUpdateProperties = original.VariableUpdateProperties
type Watcher = original.Watcher
type WatcherClient = original.WatcherClient
type WatcherListResult = original.WatcherListResult
type WatcherListResultIterator = original.WatcherListResultIterator
type WatcherListResultPage = original.WatcherListResultPage
type WatcherProperties = original.WatcherProperties
type WatcherUpdateParameters = original.WatcherUpdateParameters
type WatcherUpdateProperties = original.WatcherUpdateProperties
type Webhook = original.Webhook
type WebhookClient = original.WebhookClient
type WebhookCreateOrUpdateParameters = original.WebhookCreateOrUpdateParameters
type WebhookCreateOrUpdateProperties = original.WebhookCreateOrUpdateProperties
type WebhookListResult = original.WebhookListResult
type WebhookListResultIterator = original.WebhookListResultIterator
type WebhookListResultPage = original.WebhookListResultPage
type WebhookProperties = original.WebhookProperties
type WebhookUpdateParameters = original.WebhookUpdateParameters
type WebhookUpdateProperties = original.WebhookUpdateProperties
type WindowsProperties = original.WindowsProperties

func New(subscriptionID string) BaseClient {
	return original.New(subscriptionID)
}
func NewAccountClient(subscriptionID string) AccountClient {
	return original.NewAccountClient(subscriptionID)
}
func NewAccountClientWithBaseURI(baseURI string, subscriptionID string) AccountClient {
	return original.NewAccountClientWithBaseURI(baseURI, subscriptionID)
}
func NewAccountListResultIterator(page AccountListResultPage) AccountListResultIterator {
	return original.NewAccountListResultIterator(page)
}
func NewAccountListResultPage(cur AccountListResult, getNextPage func(context.Context, AccountListResult) (AccountListResult, error)) AccountListResultPage {
	return original.NewAccountListResultPage(cur, getNextPage)
}
func NewActivityClient(subscriptionID string) ActivityClient {
	return original.NewActivityClient(subscriptionID)
}
func NewActivityClientWithBaseURI(baseURI string, subscriptionID string) ActivityClient {
	return original.NewActivityClientWithBaseURI(baseURI, subscriptionID)
}
func NewActivityListResultIterator(page ActivityListResultPage) ActivityListResultIterator {
	return original.NewActivityListResultIterator(page)
}
func NewActivityListResultPage(cur ActivityListResult, getNextPage func(context.Context, ActivityListResult) (ActivityListResult, error)) ActivityListResultPage {
	return original.NewActivityListResultPage(cur, getNextPage)
}
func NewAgentRegistrationInformationClient(subscriptionID string) AgentRegistrationInformationClient {
	return original.NewAgentRegistrationInformationClient(subscriptionID)
}
func NewAgentRegistrationInformationClientWithBaseURI(baseURI string, subscriptionID string) AgentRegistrationInformationClient {
	return original.NewAgentRegistrationInformationClientWithBaseURI(baseURI, subscriptionID)
}
func NewCertificateClient(subscriptionID string) CertificateClient {
	return original.NewCertificateClient(subscriptionID)
}
func NewCertificateClientWithBaseURI(baseURI string, subscriptionID string) CertificateClient {
	return original.NewCertificateClientWithBaseURI(baseURI, subscriptionID)
}
func NewCertificateListResultIterator(page CertificateListResultPage) CertificateListResultIterator {
	return original.NewCertificateListResultIterator(page)
}
func NewCertificateListResultPage(cur CertificateListResult, getNextPage func(context.Context, CertificateListResult) (CertificateListResult, error)) CertificateListResultPage {
	return original.NewCertificateListResultPage(cur, getNextPage)
}
func NewConnectionClient(subscriptionID string) ConnectionClient {
	return original.NewConnectionClient(subscriptionID)
}
func NewConnectionClientWithBaseURI(baseURI string, subscriptionID string) ConnectionClient {
	return original.NewConnectionClientWithBaseURI(baseURI, subscriptionID)
}
func NewConnectionListResultIterator(page ConnectionListResultPage) ConnectionListResultIterator {
	return original.NewConnectionListResultIterator(page)
}
func NewConnectionListResultPage(cur ConnectionListResult, getNextPage func(context.Context, ConnectionListResult) (ConnectionListResult, error)) ConnectionListResultPage {
	return original.NewConnectionListResultPage(cur, getNextPage)
}
func NewConnectionTypeClient(subscriptionID string) ConnectionTypeClient {
	return original.NewConnectionTypeClient(subscriptionID)
}
func NewConnectionTypeClientWithBaseURI(baseURI string, subscriptionID string) ConnectionTypeClient {
	return original.NewConnectionTypeClientWithBaseURI(baseURI, subscriptionID)
}
func NewConnectionTypeListResultIterator(page ConnectionTypeListResultPage) ConnectionTypeListResultIterator {
	return original.NewConnectionTypeListResultIterator(page)
}
func NewConnectionTypeListResultPage(cur ConnectionTypeListResult, getNextPage func(context.Context, ConnectionTypeListResult) (ConnectionTypeListResult, error)) ConnectionTypeListResultPage {
	return original.NewConnectionTypeListResultPage(cur, getNextPage)
}
func NewCredentialClient(subscriptionID string) CredentialClient {
	return original.NewCredentialClient(subscriptionID)
}
func NewCredentialClientWithBaseURI(baseURI string, subscriptionID string) CredentialClient {
	return original.NewCredentialClientWithBaseURI(baseURI, subscriptionID)
}
func NewCredentialListResultIterator(page CredentialListResultPage) CredentialListResultIterator {
	return original.NewCredentialListResultIterator(page)
}
func NewCredentialListResultPage(cur CredentialListResult, getNextPage func(context.Context, CredentialListResult) (CredentialListResult, error)) CredentialListResultPage {
	return original.NewCredentialListResultPage(cur, getNextPage)
}
func NewDscCompilationJobClient(subscriptionID string) DscCompilationJobClient {
	return original.NewDscCompilationJobClient(subscriptionID)
}
func NewDscCompilationJobClientWithBaseURI(baseURI string, subscriptionID string) DscCompilationJobClient {
	return original.NewDscCompilationJobClientWithBaseURI(baseURI, subscriptionID)
}
func NewDscCompilationJobListResultIterator(page DscCompilationJobListResultPage) DscCompilationJobListResultIterator {
	return original.NewDscCompilationJobListResultIterator(page)
}
func NewDscCompilationJobListResultPage(cur DscCompilationJobListResult, getNextPage func(context.Context, DscCompilationJobListResult) (DscCompilationJobListResult, error)) DscCompilationJobListResultPage {
	return original.NewDscCompilationJobListResultPage(cur, getNextPage)
}
func NewDscCompilationJobStreamClient(subscriptionID string) DscCompilationJobStreamClient {
	return original.NewDscCompilationJobStreamClient(subscriptionID)
}
func NewDscCompilationJobStreamClientWithBaseURI(baseURI string, subscriptionID string) DscCompilationJobStreamClient {
	return original.NewDscCompilationJobStreamClientWithBaseURI(baseURI, subscriptionID)
}
func NewDscConfigurationClient(subscriptionID string) DscConfigurationClient {
	return original.NewDscConfigurationClient(subscriptionID)
}
func NewDscConfigurationClientWithBaseURI(baseURI string, subscriptionID string) DscConfigurationClient {
	return original.NewDscConfigurationClientWithBaseURI(baseURI, subscriptionID)
}
func NewDscConfigurationListResultIterator(page DscConfigurationListResultPage) DscConfigurationListResultIterator {
	return original.NewDscConfigurationListResultIterator(page)
}
func NewDscConfigurationListResultPage(cur DscConfigurationListResult, getNextPage func(context.Context, DscConfigurationListResult) (DscConfigurationListResult, error)) DscConfigurationListResultPage {
	return original.NewDscConfigurationListResultPage(cur, getNextPage)
}
func NewDscNodeClient(subscriptionID string) DscNodeClient {
	return original.NewDscNodeClient(subscriptionID)
}
func NewDscNodeClientWithBaseURI(baseURI string, subscriptionID string) DscNodeClient {
	return original.NewDscNodeClientWithBaseURI(baseURI, subscriptionID)
}
func NewDscNodeConfigurationClient(subscriptionID string) DscNodeConfigurationClient {
	return original.NewDscNodeConfigurationClient(subscriptionID)
}
func NewDscNodeConfigurationClientWithBaseURI(baseURI string, subscriptionID string) DscNodeConfigurationClient {
	return original.NewDscNodeConfigurationClientWithBaseURI(baseURI, subscriptionID)
}
func NewDscNodeConfigurationListResultIterator(page DscNodeConfigurationListResultPage) DscNodeConfigurationListResultIterator {
	return original.NewDscNodeConfigurationListResultIterator(page)
}
func NewDscNodeConfigurationListResultPage(cur DscNodeConfigurationListResult, getNextPage func(context.Context, DscNodeConfigurationListResult) (DscNodeConfigurationListResult, error)) DscNodeConfigurationListResultPage {
	return original.NewDscNodeConfigurationListResultPage(cur, getNextPage)
}
func NewDscNodeListResultIterator(page DscNodeListResultPage) DscNodeListResultIterator {
	return original.NewDscNodeListResultIterator(page)
}
func NewDscNodeListResultPage(cur DscNodeListResult, getNextPage func(context.Context, DscNodeListResult) (DscNodeListResult, error)) DscNodeListResultPage {
	return original.NewDscNodeListResultPage(cur, getNextPage)
}
func NewDscNodeReportListResultIterator(page DscNodeReportListResultPage) DscNodeReportListResultIterator {
	return original.NewDscNodeReportListResultIterator(page)
}
func NewDscNodeReportListResultPage(cur DscNodeReportListResult, getNextPage func(context.Context, DscNodeReportListResult) (DscNodeReportListResult, error)) DscNodeReportListResultPage {
	return original.NewDscNodeReportListResultPage(cur, getNextPage)
}
func NewFieldsClient(subscriptionID string) FieldsClient {
	return original.NewFieldsClient(subscriptionID)
}
func NewFieldsClientWithBaseURI(baseURI string, subscriptionID string) FieldsClient {
	return original.NewFieldsClientWithBaseURI(baseURI, subscriptionID)
}
func NewHybridRunbookWorkerGroupClient(subscriptionID string) HybridRunbookWorkerGroupClient {
	return original.NewHybridRunbookWorkerGroupClient(subscriptionID)
}
func NewHybridRunbookWorkerGroupClientWithBaseURI(baseURI string, subscriptionID string) HybridRunbookWorkerGroupClient {
	return original.NewHybridRunbookWorkerGroupClientWithBaseURI(baseURI, subscriptionID)
}
func NewHybridRunbookWorkerGroupsListResultIterator(page HybridRunbookWorkerGroupsListResultPage) HybridRunbookWorkerGroupsListResultIterator {
	return original.NewHybridRunbookWorkerGroupsListResultIterator(page)
}
func NewHybridRunbookWorkerGroupsListResultPage(cur HybridRunbookWorkerGroupsListResult, getNextPage func(context.Context, HybridRunbookWorkerGroupsListResult) (HybridRunbookWorkerGroupsListResult, error)) HybridRunbookWorkerGroupsListResultPage {
	return original.NewHybridRunbookWorkerGroupsListResultPage(cur, getNextPage)
}
func NewHybridRunbookWorkersClient(subscriptionID string) HybridRunbookWorkersClient {
	return original.NewHybridRunbookWorkersClient(subscriptionID)
}
func NewHybridRunbookWorkersClientWithBaseURI(baseURI string, subscriptionID string) HybridRunbookWorkersClient {
	return original.NewHybridRunbookWorkersClientWithBaseURI(baseURI, subscriptionID)
}
func NewHybridRunbookWorkersListResultIterator(page HybridRunbookWorkersListResultPage) HybridRunbookWorkersListResultIterator {
	return original.NewHybridRunbookWorkersListResultIterator(page)
}
func NewHybridRunbookWorkersListResultPage(cur HybridRunbookWorkersListResult, getNextPage func(context.Context, HybridRunbookWorkersListResult) (HybridRunbookWorkersListResult, error)) HybridRunbookWorkersListResultPage {
	return original.NewHybridRunbookWorkersListResultPage(cur, getNextPage)
}
func NewJobClient(subscriptionID string) JobClient {
	return original.NewJobClient(subscriptionID)
}
func NewJobClientWithBaseURI(baseURI string, subscriptionID string) JobClient {
	return original.NewJobClientWithBaseURI(baseURI, subscriptionID)
}
func NewJobListResultV2Iterator(page JobListResultV2Page) JobListResultV2Iterator {
	return original.NewJobListResultV2Iterator(page)
}
func NewJobListResultV2Page(cur JobListResultV2, getNextPage func(context.Context, JobListResultV2) (JobListResultV2, error)) JobListResultV2Page {
	return original.NewJobListResultV2Page(cur, getNextPage)
}
func NewJobScheduleClient(subscriptionID string) JobScheduleClient {
	return original.NewJobScheduleClient(subscriptionID)
}
func NewJobScheduleClientWithBaseURI(baseURI string, subscriptionID string) JobScheduleClient {
	return original.NewJobScheduleClientWithBaseURI(baseURI, subscriptionID)
}
func NewJobScheduleListResultIterator(page JobScheduleListResultPage) JobScheduleListResultIterator {
	return original.NewJobScheduleListResultIterator(page)
}
func NewJobScheduleListResultPage(cur JobScheduleListResult, getNextPage func(context.Context, JobScheduleListResult) (JobScheduleListResult, error)) JobScheduleListResultPage {
	return original.NewJobScheduleListResultPage(cur, getNextPage)
}
func NewJobStreamClient(subscriptionID string) JobStreamClient {
	return original.NewJobStreamClient(subscriptionID)
}
func NewJobStreamClientWithBaseURI(baseURI string, subscriptionID string) JobStreamClient {
	return original.NewJobStreamClientWithBaseURI(baseURI, subscriptionID)
}
func NewJobStreamListResultIterator(page JobStreamListResultPage) JobStreamListResultIterator {
	return original.NewJobStreamListResultIterator(page)
}
func NewJobStreamListResultPage(cur JobStreamListResult, getNextPage func(context.Context, JobStreamListResult) (JobStreamListResult, error)) JobStreamListResultPage {
	return original.NewJobStreamListResultPage(cur, getNextPage)
}
func NewKeysClient(subscriptionID string) KeysClient {
	return original.NewKeysClient(subscriptionID)
}
func NewKeysClientWithBaseURI(baseURI string, subscriptionID string) KeysClient {
	return original.NewKeysClientWithBaseURI(baseURI, subscriptionID)
}
func NewLinkedWorkspaceClient(subscriptionID string) LinkedWorkspaceClient {
	return original.NewLinkedWorkspaceClient(subscriptionID)
}
func NewLinkedWorkspaceClientWithBaseURI(baseURI string, subscriptionID string) LinkedWorkspaceClient {
	return original.NewLinkedWorkspaceClientWithBaseURI(baseURI, subscriptionID)
}
func NewModuleClient(subscriptionID string) ModuleClient {
	return original.NewModuleClient(subscriptionID)
}
func NewModuleClientWithBaseURI(baseURI string, subscriptionID string) ModuleClient {
	return original.NewModuleClientWithBaseURI(baseURI, subscriptionID)
}
func NewModuleListResultIterator(page ModuleListResultPage) ModuleListResultIterator {
	return original.NewModuleListResultIterator(page)
}
func NewModuleListResultPage(cur ModuleListResult, getNextPage func(context.Context, ModuleListResult) (ModuleListResult, error)) ModuleListResultPage {
	return original.NewModuleListResultPage(cur, getNextPage)
}
func NewNodeCountInformationClient(subscriptionID string) NodeCountInformationClient {
	return original.NewNodeCountInformationClient(subscriptionID)
}
func NewNodeCountInformationClientWithBaseURI(baseURI string, subscriptionID string) NodeCountInformationClient {
	return original.NewNodeCountInformationClientWithBaseURI(baseURI, subscriptionID)
}
func NewNodeReportsClient(subscriptionID string) NodeReportsClient {
	return original.NewNodeReportsClient(subscriptionID)
}
func NewNodeReportsClientWithBaseURI(baseURI string, subscriptionID string) NodeReportsClient {
	return original.NewNodeReportsClientWithBaseURI(baseURI, subscriptionID)
}
func NewObjectDataTypesClient(subscriptionID string) ObjectDataTypesClient {
	return original.NewObjectDataTypesClient(subscriptionID)
}
func NewObjectDataTypesClientWithBaseURI(baseURI string, subscriptionID string) ObjectDataTypesClient {
	return original.NewObjectDataTypesClientWithBaseURI(baseURI, subscriptionID)
}
func NewOperationsClient(subscriptionID string) OperationsClient {
	return original.NewOperationsClient(subscriptionID)
}
func NewOperationsClientWithBaseURI(baseURI string, subscriptionID string) OperationsClient {
	return original.NewOperationsClientWithBaseURI(baseURI, subscriptionID)
}
func NewPrivateEndpointConnectionsClient(subscriptionID string) PrivateEndpointConnectionsClient {
	return original.NewPrivateEndpointConnectionsClient(subscriptionID)
}
func NewPrivateEndpointConnectionsClientWithBaseURI(baseURI string, subscriptionID string) PrivateEndpointConnectionsClient {
	return original.NewPrivateEndpointConnectionsClientWithBaseURI(baseURI, subscriptionID)
}
func NewPrivateLinkResourcesClient(subscriptionID string) PrivateLinkResourcesClient {
	return original.NewPrivateLinkResourcesClient(subscriptionID)
}
func NewPrivateLinkResourcesClientWithBaseURI(baseURI string, subscriptionID string) PrivateLinkResourcesClient {
	return original.NewPrivateLinkResourcesClientWithBaseURI(baseURI, subscriptionID)
}
func NewPython2PackageClient(subscriptionID string) Python2PackageClient {
	return original.NewPython2PackageClient(subscriptionID)
}
func NewPython2PackageClientWithBaseURI(baseURI string, subscriptionID string) Python2PackageClient {
	return original.NewPython2PackageClientWithBaseURI(baseURI, subscriptionID)
}
func NewRunbookClient(subscriptionID string) RunbookClient {
	return original.NewRunbookClient(subscriptionID)
}
func NewRunbookClientWithBaseURI(baseURI string, subscriptionID string) RunbookClient {
	return original.NewRunbookClientWithBaseURI(baseURI, subscriptionID)
}
func NewRunbookDraftClient(subscriptionID string) RunbookDraftClient {
	return original.NewRunbookDraftClient(subscriptionID)
}
func NewRunbookDraftClientWithBaseURI(baseURI string, subscriptionID string) RunbookDraftClient {
	return original.NewRunbookDraftClientWithBaseURI(baseURI, subscriptionID)
}
func NewRunbookListResultIterator(page RunbookListResultPage) RunbookListResultIterator {
	return original.NewRunbookListResultIterator(page)
}
func NewRunbookListResultPage(cur RunbookListResult, getNextPage func(context.Context, RunbookListResult) (RunbookListResult, error)) RunbookListResultPage {
	return original.NewRunbookListResultPage(cur, getNextPage)
}
func NewScheduleClient(subscriptionID string) ScheduleClient {
	return original.NewScheduleClient(subscriptionID)
}
func NewScheduleClientWithBaseURI(baseURI string, subscriptionID string) ScheduleClient {
	return original.NewScheduleClientWithBaseURI(baseURI, subscriptionID)
}
func NewScheduleListResultIterator(page ScheduleListResultPage) ScheduleListResultIterator {
	return original.NewScheduleListResultIterator(page)
}
func NewScheduleListResultPage(cur ScheduleListResult, getNextPage func(context.Context, ScheduleListResult) (ScheduleListResult, error)) ScheduleListResultPage {
	return original.NewScheduleListResultPage(cur, getNextPage)
}
func NewSoftwareUpdateConfigurationMachineRunsClient(subscriptionID string) SoftwareUpdateConfigurationMachineRunsClient {
	return original.NewSoftwareUpdateConfigurationMachineRunsClient(subscriptionID)
}
func NewSoftwareUpdateConfigurationMachineRunsClientWithBaseURI(baseURI string, subscriptionID string) SoftwareUpdateConfigurationMachineRunsClient {
	return original.NewSoftwareUpdateConfigurationMachineRunsClientWithBaseURI(baseURI, subscriptionID)
}
func NewSoftwareUpdateConfigurationRunsClient(subscriptionID string) SoftwareUpdateConfigurationRunsClient {
	return original.NewSoftwareUpdateConfigurationRunsClient(subscriptionID)
}
func NewSoftwareUpdateConfigurationRunsClientWithBaseURI(baseURI string, subscriptionID string) SoftwareUpdateConfigurationRunsClient {
	return original.NewSoftwareUpdateConfigurationRunsClientWithBaseURI(baseURI, subscriptionID)
}
func NewSoftwareUpdateConfigurationsClient(subscriptionID string) SoftwareUpdateConfigurationsClient {
	return original.NewSoftwareUpdateConfigurationsClient(subscriptionID)
}
func NewSoftwareUpdateConfigurationsClientWithBaseURI(baseURI string, subscriptionID string) SoftwareUpdateConfigurationsClient {
	return original.NewSoftwareUpdateConfigurationsClientWithBaseURI(baseURI, subscriptionID)
}
func NewSourceControlClient(subscriptionID string) SourceControlClient {
	return original.NewSourceControlClient(subscriptionID)
}
func NewSourceControlClientWithBaseURI(baseURI string, subscriptionID string) SourceControlClient {
	return original.NewSourceControlClientWithBaseURI(baseURI, subscriptionID)
}
func NewSourceControlListResultIterator(page SourceControlListResultPage) SourceControlListResultIterator {
	return original.NewSourceControlListResultIterator(page)
}
func NewSourceControlListResultPage(cur SourceControlListResult, getNextPage func(context.Context, SourceControlListResult) (SourceControlListResult, error)) SourceControlListResultPage {
	return original.NewSourceControlListResultPage(cur, getNextPage)
}
func NewSourceControlSyncJobClient(subscriptionID string) SourceControlSyncJobClient {
	return original.NewSourceControlSyncJobClient(subscriptionID)
}
func NewSourceControlSyncJobClientWithBaseURI(baseURI string, subscriptionID string) SourceControlSyncJobClient {
	return original.NewSourceControlSyncJobClientWithBaseURI(baseURI, subscriptionID)
}
func NewSourceControlSyncJobListResultIterator(page SourceControlSyncJobListResultPage) SourceControlSyncJobListResultIterator {
	return original.NewSourceControlSyncJobListResultIterator(page)
}
func NewSourceControlSyncJobListResultPage(cur SourceControlSyncJobListResult, getNextPage func(context.Context, SourceControlSyncJobListResult) (SourceControlSyncJobListResult, error)) SourceControlSyncJobListResultPage {
	return original.NewSourceControlSyncJobListResultPage(cur, getNextPage)
}
func NewSourceControlSyncJobStreamsClient(subscriptionID string) SourceControlSyncJobStreamsClient {
	return original.NewSourceControlSyncJobStreamsClient(subscriptionID)
}
func NewSourceControlSyncJobStreamsClientWithBaseURI(baseURI string, subscriptionID string) SourceControlSyncJobStreamsClient {
	return original.NewSourceControlSyncJobStreamsClientWithBaseURI(baseURI, subscriptionID)
}
func NewSourceControlSyncJobStreamsListBySyncJobIterator(page SourceControlSyncJobStreamsListBySyncJobPage) SourceControlSyncJobStreamsListBySyncJobIterator {
	return original.NewSourceControlSyncJobStreamsListBySyncJobIterator(page)
}
func NewSourceControlSyncJobStreamsListBySyncJobPage(cur SourceControlSyncJobStreamsListBySyncJob, getNextPage func(context.Context, SourceControlSyncJobStreamsListBySyncJob) (SourceControlSyncJobStreamsListBySyncJob, error)) SourceControlSyncJobStreamsListBySyncJobPage {
	return original.NewSourceControlSyncJobStreamsListBySyncJobPage(cur, getNextPage)
}
func NewStatisticsClient(subscriptionID string) StatisticsClient {
	return original.NewStatisticsClient(subscriptionID)
}
func NewStatisticsClientWithBaseURI(baseURI string, subscriptionID string) StatisticsClient {
	return original.NewStatisticsClientWithBaseURI(baseURI, subscriptionID)
}
func NewTestJobClient(subscriptionID string) TestJobClient {
	return original.NewTestJobClient(subscriptionID)
}
func NewTestJobClientWithBaseURI(baseURI string, subscriptionID string) TestJobClient {
	return original.NewTestJobClientWithBaseURI(baseURI, subscriptionID)
}
func NewTestJobStreamsClient(subscriptionID string) TestJobStreamsClient {
	return original.NewTestJobStreamsClient(subscriptionID)
}
func NewTestJobStreamsClientWithBaseURI(baseURI string, subscriptionID string) TestJobStreamsClient {
	return original.NewTestJobStreamsClientWithBaseURI(baseURI, subscriptionID)
}
func NewUsagesClient(subscriptionID string) UsagesClient {
	return original.NewUsagesClient(subscriptionID)
}
func NewUsagesClientWithBaseURI(baseURI string, subscriptionID string) UsagesClient {
	return original.NewUsagesClientWithBaseURI(baseURI, subscriptionID)
}
func NewVariableClient(subscriptionID string) VariableClient {
	return original.NewVariableClient(subscriptionID)
}
func NewVariableClientWithBaseURI(baseURI string, subscriptionID string) VariableClient {
	return original.NewVariableClientWithBaseURI(baseURI, subscriptionID)
}
func NewVariableListResultIterator(page VariableListResultPage) VariableListResultIterator {
	return original.NewVariableListResultIterator(page)
}
func NewVariableListResultPage(cur VariableListResult, getNextPage func(context.Context, VariableListResult) (VariableListResult, error)) VariableListResultPage {
	return original.NewVariableListResultPage(cur, getNextPage)
}
func NewWatcherClient(subscriptionID string) WatcherClient {
	return original.NewWatcherClient(subscriptionID)
}
func NewWatcherClientWithBaseURI(baseURI string, subscriptionID string) WatcherClient {
	return original.NewWatcherClientWithBaseURI(baseURI, subscriptionID)
}
func NewWatcherListResultIterator(page WatcherListResultPage) WatcherListResultIterator {
	return original.NewWatcherListResultIterator(page)
}
func NewWatcherListResultPage(cur WatcherListResult, getNextPage func(context.Context, WatcherListResult) (WatcherListResult, error)) WatcherListResultPage {
	return original.NewWatcherListResultPage(cur, getNextPage)
}
func NewWebhookClient(subscriptionID string) WebhookClient {
	return original.NewWebhookClient(subscriptionID)
}
func NewWebhookClientWithBaseURI(baseURI string, subscriptionID string) WebhookClient {
	return original.NewWebhookClientWithBaseURI(baseURI, subscriptionID)
}
func NewWebhookListResultIterator(page WebhookListResultPage) WebhookListResultIterator {
	return original.NewWebhookListResultIterator(page)
}
func NewWebhookListResultPage(cur WebhookListResult, getNextPage func(context.Context, WebhookListResult) (WebhookListResult, error)) WebhookListResultPage {
	return original.NewWebhookListResultPage(cur, getNextPage)
}
func NewWithBaseURI(baseURI string, subscriptionID string) BaseClient {
	return original.NewWithBaseURI(baseURI, subscriptionID)
}
func PossibleAccountStateValues() []AccountState {
	return original.PossibleAccountStateValues()
}
func PossibleAgentRegistrationKeyNameValues() []AgentRegistrationKeyName {
	return original.PossibleAgentRegistrationKeyNameValues()
}
func PossibleContentSourceTypeValues() []ContentSourceType {
	return original.PossibleContentSourceTypeValues()
}
func PossibleCountTypeValues() []CountType {
	return original.PossibleCountTypeValues()
}
func PossibleCreatedByTypeValues() []CreatedByType {
	return original.PossibleCreatedByTypeValues()
}
func PossibleDscConfigurationProvisioningStateValues() []DscConfigurationProvisioningState {
	return original.PossibleDscConfigurationProvisioningStateValues()
}
func PossibleDscConfigurationStateValues() []DscConfigurationState {
	return original.PossibleDscConfigurationStateValues()
}
func PossibleEncryptionKeySourceTypeValues() []EncryptionKeySourceType {
	return original.PossibleEncryptionKeySourceTypeValues()
}
func PossibleGraphRunbookTypeValues() []GraphRunbookType {
	return original.PossibleGraphRunbookTypeValues()
}
func PossibleGroupTypeEnumValues() []GroupTypeEnum {
	return original.PossibleGroupTypeEnumValues()
}
func PossibleHTTPStatusCodeValues() []HTTPStatusCode {
	return original.PossibleHTTPStatusCodeValues()
}
func PossibleJobProvisioningStateValues() []JobProvisioningState {
	return original.PossibleJobProvisioningStateValues()
}
func PossibleJobStatusValues() []JobStatus {
	return original.PossibleJobStatusValues()
}
func PossibleJobStreamTypeValues() []JobStreamType {
	return original.PossibleJobStreamTypeValues()
}
func PossibleKeyNameValues() []KeyName {
	return original.PossibleKeyNameValues()
}
func PossibleKeyPermissionsValues() []KeyPermissions {
	return original.PossibleKeyPermissionsValues()
}
func PossibleLinuxUpdateClassesValues() []LinuxUpdateClasses {
	return original.PossibleLinuxUpdateClassesValues()
}
func PossibleModuleProvisioningStateValues() []ModuleProvisioningState {
	return original.PossibleModuleProvisioningStateValues()
}
func PossibleOperatingSystemTypeValues() []OperatingSystemType {
	return original.PossibleOperatingSystemTypeValues()
}
func PossibleProvisioningStateValues() []ProvisioningState {
	return original.PossibleProvisioningStateValues()
}
func PossibleResourceIdentityTypeValues() []ResourceIdentityType {
	return original.PossibleResourceIdentityTypeValues()
}
func PossibleRunbookProvisioningStateValues() []RunbookProvisioningState {
	return original.PossibleRunbookProvisioningStateValues()
}
func PossibleRunbookStateValues() []RunbookState {
	return original.PossibleRunbookStateValues()
}
func PossibleRunbookTypeEnumValues() []RunbookTypeEnum {
	return original.PossibleRunbookTypeEnumValues()
}
func PossibleScheduleDayValues() []ScheduleDay {
	return original.PossibleScheduleDayValues()
}
func PossibleScheduleFrequencyValues() []ScheduleFrequency {
	return original.PossibleScheduleFrequencyValues()
}
func PossibleSkuNameEnumValues() []SkuNameEnum {
	return original.PossibleSkuNameEnumValues()
}
func PossibleSourceTypeValues() []SourceType {
	return original.PossibleSourceTypeValues()
}
func PossibleStreamTypeValues() []StreamType {
	return original.PossibleStreamTypeValues()
}
func PossibleSyncTypeValues() []SyncType {
	return original.PossibleSyncTypeValues()
}
func PossibleTagOperatorsValues() []TagOperators {
	return original.PossibleTagOperatorsValues()
}
func PossibleTokenTypeValues() []TokenType {
	return original.PossibleTokenTypeValues()
}
func PossibleWindowsUpdateClassesValues() []WindowsUpdateClasses {
	return original.PossibleWindowsUpdateClassesValues()
}
func PossibleWorkerTypeValues() []WorkerType {
	return original.PossibleWorkerTypeValues()
}
func UserAgent() string {
	return original.UserAgent() + " profiles/preview"
}
func Version() string {
	return original.Version()
}
