//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package mysqlapi

import original "github.com/Azure/azure-sdk-for-go/services/mysql/mgmt/2020-01-01/mysql/mysqlapi"

type AdvisorsClientAPI = original.AdvisorsClientAPI
type BaseClientAPI = original.BaseClientAPI
type CheckNameAvailabilityClientAPI = original.CheckNameAvailabilityClientAPI
type ConfigurationsClientAPI = original.ConfigurationsClientAPI
type DatabasesClientAPI = original.DatabasesClientAPI
type FirewallRulesClientAPI = original.FirewallRulesClientAPI
type LocationBasedPerformanceTierClientAPI = original.LocationBasedPerformanceTierClientAPI
type LocationBasedRecommendedActionSessionsOperationStatusClientAPI = original.LocationBasedRecommendedActionSessionsOperationStatusClientAPI
type LocationBasedRecommendedActionSessionsResultClientAPI = original.LocationBasedRecommendedActionSessionsResultClientAPI
type LogFilesClientAPI = original.LogFilesClientAPI
type OperationsClientAPI = original.OperationsClientAPI
type PrivateEndpointConnectionsClientAPI = original.PrivateEndpointConnectionsClientAPI
type PrivateLinkResourcesClientAPI = original.PrivateLinkResourcesClientAPI
type QueryTextsClientAPI = original.QueryTextsClientAPI
type RecommendedActionsClientAPI = original.RecommendedActionsClientAPI
type RecoverableServersClientAPI = original.RecoverableServersClientAPI
type ReplicasClientAPI = original.ReplicasClientAPI
type ServerAdministratorsClientAPI = original.ServerAdministratorsClientAPI
type ServerBasedPerformanceTierClientAPI = original.ServerBasedPerformanceTierClientAPI
type ServerKeysClientAPI = original.ServerKeysClientAPI
type ServerParametersClientAPI = original.ServerParametersClientAPI
type ServerSecurityAlertPoliciesClientAPI = original.ServerSecurityAlertPoliciesClientAPI
type ServersClientAPI = original.ServersClientAPI
type TopQueryStatisticsClientAPI = original.TopQueryStatisticsClientAPI
type VirtualNetworkRulesClientAPI = original.VirtualNetworkRulesClientAPI
type WaitStatisticsClientAPI = original.WaitStatisticsClientAPI
