//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package costmanagementapi

import original "github.com/Azure/azure-sdk-for-go/services/costmanagement/mgmt/2020-06-01/costmanagement/costmanagementapi"

type AlertsClientAPI = original.AlertsClientAPI
type DimensionsClientAPI = original.DimensionsClientAPI
type ExportsClientAPI = original.ExportsClientAPI
type ForecastClientAPI = original.ForecastClientAPI
type OperationsClientAPI = original.OperationsClientAPI
type QueryClientAPI = original.QueryClientAPI
type ViewsClientAPI = original.ViewsClientAPI
