//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package hdinsightapi

import original "github.com/Azure/azure-sdk-for-go/services/hdinsight/mgmt/2021-06-01/hdinsight/hdinsightapi"

type ApplicationsClientAPI = original.ApplicationsClientAPI
type ClustersClientAPI = original.ClustersClientAPI
type ConfigurationsClientAPI = original.ConfigurationsClientAPI
type ExtensionsClientAPI = original.ExtensionsClientAPI
type LocationsClientAPI = original.LocationsClientAPI
type OperationsClientAPI = original.OperationsClientAPI
type PrivateEndpointConnectionsClientAPI = original.PrivateEndpointConnectionsClientAPI
type PrivateLinkResourcesClientAPI = original.PrivateLinkResourcesClientAPI
type ScriptActionsClientAPI = original.ScriptActionsClientAPI
type ScriptExecutionHistoryClientAPI = original.ScriptExecutionHistoryClientAPI
type VirtualMachinesClientAPI = original.VirtualMachinesClientAPI
