//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package operationalinsightsapi

import original "github.com/Azure/azure-sdk-for-go/services/preview/operationalinsights/mgmt/2022-02-01-preview/operationalinsights/operationalinsightsapi"

type AvailableServiceTiersClientAPI = original.AvailableServiceTiersClientAPI
type ClustersClientAPI = original.ClustersClientAPI
type DataExportsClientAPI = original.DataExportsClientAPI
type DataSourcesClientAPI = original.DataSourcesClientAPI
type DeletedWorkspacesClientAPI = original.DeletedWorkspacesClientAPI
type GatewaysClientAPI = original.GatewaysClientAPI
type IntelligencePacksClientAPI = original.IntelligencePacksClientAPI
type LinkedServicesClientAPI = original.LinkedServicesClientAPI
type LinkedStorageAccountsClientAPI = original.LinkedStorageAccountsClientAPI
type ManagementGroupsClientAPI = original.ManagementGroupsClientAPI
type OperationStatusesClientAPI = original.OperationStatusesClientAPI
type OperationsClientAPI = original.OperationsClientAPI
type QueriesClientAPI = original.QueriesClientAPI
type QueryPacksClientAPI = original.QueryPacksClientAPI
type SavedSearchesClientAPI = original.SavedSearchesClientAPI
type SchemaClientAPI = original.SchemaClientAPI
type SharedKeysClientAPI = original.SharedKeysClientAPI
type StorageInsightConfigsClientAPI = original.StorageInsightConfigsClientAPI
type TablesClientAPI = original.TablesClientAPI
type UsagesClientAPI = original.UsagesClientAPI
type WorkspacePurgeClientAPI = original.WorkspacePurgeClientAPI
type WorkspacesClientAPI = original.WorkspacesClientAPI
