//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package storagesyncapi

import original "github.com/Azure/azure-sdk-for-go/services/storagesync/mgmt/2020-03-01/storagesync/storagesyncapi"

type CloudEndpointsClientAPI = original.CloudEndpointsClientAPI
type OperationStatusClientAPI = original.OperationStatusClientAPI
type OperationsClientAPI = original.OperationsClientAPI
type PrivateEndpointConnectionsClientAPI = original.PrivateEndpointConnectionsClientAPI
type PrivateLinkResourcesClientAPI = original.PrivateLinkResourcesClientAPI
type RegisteredServersClientAPI = original.RegisteredServersClientAPI
type ServerEndpointsClientAPI = original.ServerEndpointsClientAPI
type ServicesClientAPI = original.ServicesClientAPI
type SyncGroupsClientAPI = original.SyncGroupsClientAPI
type WorkflowsClientAPI = original.WorkflowsClientAPI
