//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package accountapi

import original "github.com/Azure/azure-sdk-for-go/services/datalake/analytics/mgmt/2016-11-01/account/accountapi"

type AccountsClientAPI = original.AccountsClientAPI
type ComputePoliciesClientAPI = original.ComputePoliciesClientAPI
type DataLakeStoreAccountsClientAPI = original.DataLakeStoreAccountsClientAPI
type FirewallRulesClientAPI = original.FirewallRulesClientAPI
type LocationsClientAPI = original.LocationsClientAPI
type OperationsClientAPI = original.OperationsClientAPI
type StorageAccountsClientAPI = original.StorageAccountsClientAPI
