//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package adhybridhealthserviceapi

import original "github.com/Azure/azure-sdk-for-go/services/adhybridhealthservice/mgmt/2014-01-01/adhybridhealthservice/adhybridhealthserviceapi"

type AdDomainServiceMembersClientAPI = original.AdDomainServiceMembersClientAPI
type AddsServiceClientAPI = original.AddsServiceClientAPI
type AddsServiceMembersClientAPI = original.AddsServiceMembersClientAPI
type AddsServicesClientAPI = original.AddsServicesClientAPI
type AddsServicesReplicationStatusClientAPI = original.AddsServicesReplicationStatusClientAPI
type AddsServicesServiceMembersClientAPI = original.AddsServicesServiceMembersClientAPI
type AddsServicesUserPreferenceClientAPI = original.AddsServicesUserPreferenceClientAPI
type AlertsClientAPI = original.AlertsClientAPI
type ConfigurationClientAPI = original.ConfigurationClientAPI
type DimensionsClientAPI = original.DimensionsClientAPI
type ListClientAPI = original.ListClientAPI
type OperationsClientAPI = original.OperationsClientAPI
type ReportsClientAPI = original.ReportsClientAPI
type ServiceClientAPI = original.ServiceClientAPI
type ServiceMembersClientAPI = original.ServiceMembersClientAPI
type ServicesClientAPI = original.ServicesClientAPI
type UpdateClientAPI = original.UpdateClientAPI
