//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package mediaapi

import original "github.com/Azure/azure-sdk-for-go/services/mediaservices/mgmt/2021-11-01/media/mediaapi"

type AccountFiltersClientAPI = original.AccountFiltersClientAPI
type AssetFiltersClientAPI = original.AssetFiltersClientAPI
type AssetsClientAPI = original.AssetsClientAPI
type ContentKeyPoliciesClientAPI = original.ContentKeyPoliciesClientAPI
type JobsClientAPI = original.JobsClientAPI
type LiveEventsClientAPI = original.LiveEventsClientAPI
type LiveOutputsClientAPI = original.LiveOutputsClientAPI
type LocationsClientAPI = original.LocationsClientAPI
type MediaservicesClientAPI = original.MediaservicesClientAPI
type OperationResultsClientAPI = original.OperationResultsClientAPI
type OperationStatusesClientAPI = original.OperationStatusesClientAPI
type OperationsClientAPI = original.OperationsClientAPI
type PrivateEndpointConnectionsClientAPI = original.PrivateEndpointConnectionsClientAPI
type PrivateLinkResourcesClientAPI = original.PrivateLinkResourcesClientAPI
type StreamingEndpointsClientAPI = original.StreamingEndpointsClientAPI
type StreamingLocatorsClientAPI = original.StreamingLocatorsClientAPI
type StreamingPoliciesClientAPI = original.StreamingPoliciesClientAPI
type TracksClientAPI = original.TracksClientAPI
type TransformsClientAPI = original.TransformsClientAPI
