//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package azuredataapi

import original "github.com/Azure/azure-sdk-for-go/services/preview/azuredata/mgmt/2019-07-24-preview/azuredata/azuredataapi"

type DataControllersClientAPI = original.DataControllersClientAPI
type OperationsClientAPI = original.OperationsClientAPI
type PostgresInstancesClientAPI = original.PostgresInstancesClientAPI
type SQLManagedInstancesClientAPI = original.SQLManagedInstancesClientAPI
type SQLServerInstancesClientAPI = original.SQLServerInstancesClientAPI
type SQLServerRegistrationsClientAPI = original.SQLServerRegistrationsClientAPI
type SQLServersClientAPI = original.SQLServersClientAPI
