//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package quotaapi

import original "github.com/Azure/azure-sdk-for-go/services/preview/quota/mgmt/2021-03-15-preview/quota/quotaapi"

type ClientAPI = original.ClientAPI
type OperationClientAPI = original.OperationClientAPI
type RequestStatusClientAPI = original.RequestStatusClientAPI
type UsagesClientAPI = original.UsagesClientAPI
