//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package mysqlapi

import original "github.com/Azure/azure-sdk-for-go/services/preview/mysql/mgmt/2017-12-01-preview/mysql/mysqlapi"

type CheckNameAvailabilityClientAPI = original.CheckNameAvailabilityClientAPI
type ConfigurationsClientAPI = original.ConfigurationsClientAPI
type DatabasesClientAPI = original.DatabasesClientAPI
type FirewallRulesClientAPI = original.FirewallRulesClientAPI
type LocationBasedPerformanceTierClientAPI = original.LocationBasedPerformanceTierClientAPI
type LogFilesClientAPI = original.LogFilesClientAPI
type OperationsClientAPI = original.OperationsClientAPI
type ReplicasClientAPI = original.ReplicasClientAPI
type ServerAdministratorsClientAPI = original.ServerAdministratorsClientAPI
type ServerSecurityAlertPoliciesClientAPI = original.ServerSecurityAlertPoliciesClientAPI
type ServersClientAPI = original.ServersClientAPI
type VirtualNetworkRulesClientAPI = original.VirtualNetworkRulesClientAPI
