package newssearchapi

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.
//
// Code generated by Microsoft (R) AutoRest Code Generator.
// Changes may cause incorrect behavior and will be lost if the code is regenerated.

import (
	"context"
	"github.com/Azure/azure-sdk-for-go/services/cognitiveservices/v1.0/newssearch"
)

// NewsClientAPI contains the set of methods on the NewsClient type.
type NewsClientAPI interface {
	Category(ctx context.Context, acceptLanguage string, userAgent string, clientID string, clientIP string, location string, countryCode string, category string, count *int32, headlineCount *int32, market string, offset *int32, originalImage *bool, safeSearch newssearch.SafeSearch, setLang string, textDecorations *bool, textFormat newssearch.TextFormat) (result newssearch.News, err error)
	Search(ctx context.Context, query string, acceptLanguage string, userAgent string, clientID string, clientIP string, location string, countryCode string, count *int32, freshness newssearch.Freshness, market string, offset *int32, originalImage *bool, safeSearch newssearch.SafeSearch, setLang string, sortBy string, textDecorations *bool, textFormat newssearch.TextFormat) (result newssearch.News, err error)
	Trending(ctx context.Context, acceptLanguage string, userAgent string, clientID string, clientIP string, location string, countryCode string, count *int32, market string, offset *int32, safeSearch newssearch.SafeSearch, setLang string, since *int64, sortBy string, textDecorations *bool, textFormat newssearch.TextFormat) (result newssearch.TrendingTopics, err error)
}

var _ NewsClientAPI = (*newssearch.NewsClient)(nil)
