//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package kubernetesconfigurationapi

import original "github.com/Azure/azure-sdk-for-go/services/kubernetesconfiguration/mgmt/2022-07-01/kubernetesconfiguration/kubernetesconfigurationapi"

type ExtensionsClientAPI = original.ExtensionsClientAPI
type FluxConfigOperationStatusClientAPI = original.FluxConfigOperationStatusClientAPI
type FluxConfigurationsClientAPI = original.FluxConfigurationsClientAPI
type OperationStatusClientAPI = original.OperationStatusClientAPI
type OperationsClientAPI = original.OperationsClientAPI
type SourceControlConfigurationsClientAPI = original.SourceControlConfigurationsClientAPI
