/*
Package sdk provides Go packages for managing and using Azure services.

GitHub repo: https://github.com/Azure/azure-sdk-for-go

Official documentation: https://docs.microsoft.com/azure/go

API reference: https://godoc.org/github.com/Azure/azure-sdk-for-go

Samples: https://github.com/Azure-Samples/azure-sdk-for-go-samples
*/
package sdk

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.
