//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package personalizerapi

import original "github.com/Azure/azure-sdk-for-go/services/personalizer/v1.0/personalizer/personalizerapi"

type BaseClientAPI = original.BaseClientAPI
type EvaluationsClientAPI = original.EvaluationsClientAPI
type EventsClientAPI = original.EventsClientAPI
type LogClientAPI = original.LogClientAPI
type ModelClientAPI = original.ModelClientAPI
type PolicyClientAPI = original.PolicyClientAPI
type ServiceConfigurationClientAPI = original.ServiceConfigurationClientAPI
