//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package datadogapi

import original "github.com/Azure/azure-sdk-for-go/services/preview/datadog/mgmt/2020-02-01-preview/datadog/datadogapi"

type MarketplaceAgreementsClientAPI = original.MarketplaceAgreementsClientAPI
type MonitorsClientAPI = original.MonitorsClientAPI
type OperationsClientAPI = original.OperationsClientAPI
type SingleSignOnConfigurationsClientAPI = original.SingleSignOnConfigurationsClientAPI
type TagRulesClientAPI = original.TagRulesClientAPI
