package contentmoderator

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.
//
// Code generated by Microsoft (R) AutoRest Code Generator.
// Changes may cause incorrect behavior and will be lost if the code is regenerated.

// StatusEnum enumerates the values for status enum.
type StatusEnum string

const (
	// Complete ...
	Complete StatusEnum = "Complete"
	// Pending ...
	Pending StatusEnum = "Pending"
	// Unpublished ...
	Unpublished StatusEnum = "Unpublished"
)

// PossibleStatusEnumValues returns an array of possible values for the StatusEnum const type.
func PossibleStatusEnumValues() []StatusEnum {
	return []StatusEnum{Complete, Pending, Unpublished}
}

// Type enumerates the values for type.
type Type string

const (
	// TypeImage ...
	TypeImage Type = "Image"
	// TypeText ...
	TypeText Type = "Text"
)

// PossibleTypeValues returns an array of possible values for the Type const type.
func PossibleTypeValues() []Type {
	return []Type{TypeImage, TypeText}
}
