//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package monitor

import original "github.com/Azure/azure-sdk-for-go/services/preview/monitor/2018-09-01-preview/monitor"

const (
	DefaultBaseURI = original.DefaultBaseURI
)

type APIError = original.APIError
type APIFailureResponse = original.APIFailureResponse
type AzureMetricsBaseData = original.AzureMetricsBaseData
type AzureMetricsData = original.AzureMetricsData
type AzureMetricsDocument = original.AzureMetricsDocument
type AzureMetricsResult = original.AzureMetricsResult
type AzureTimeSeriesData = original.AzureTimeSeriesData
type BaseClient = original.BaseClient
type MetricsClient = original.MetricsClient

func New() BaseClient {
	return original.New()
}
func NewMetricsClient() MetricsClient {
	return original.NewMetricsClient()
}
func NewMetricsClientWithBaseURI(baseURI string) MetricsClient {
	return original.NewMetricsClientWithBaseURI(baseURI)
}
func NewWithBaseURI(baseURI string) BaseClient {
	return original.NewWithBaseURI(baseURI)
}
func UserAgent() string {
	return original.UserAgent() + " profiles/preview"
}
func Version() string {
	return original.Version()
}
