//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package storageapi

import original "github.com/Azure/azure-sdk-for-go/services/preview/storage/mgmt/2020-08-01-preview/storage/storageapi"

type AccountsClientAPI = original.AccountsClientAPI
type BlobContainersClientAPI = original.BlobContainersClientAPI
type BlobInventoryPoliciesClientAPI = original.BlobInventoryPoliciesClientAPI
type BlobServicesClientAPI = original.BlobServicesClientAPI
type DeletedAccountsClientAPI = original.DeletedAccountsClientAPI
type EncryptionScopesClientAPI = original.EncryptionScopesClientAPI
type FileServicesClientAPI = original.FileServicesClientAPI
type FileSharesClientAPI = original.FileSharesClientAPI
type ManagementPoliciesClientAPI = original.ManagementPoliciesClientAPI
type ObjectReplicationPoliciesClientAPI = original.ObjectReplicationPoliciesClientAPI
type OperationsClientAPI = original.OperationsClientAPI
type PrivateEndpointConnectionsClientAPI = original.PrivateEndpointConnectionsClientAPI
type PrivateLinkResourcesClientAPI = original.PrivateLinkResourcesClientAPI
type QueueClientAPI = original.QueueClientAPI
type QueueServicesClientAPI = original.QueueServicesClientAPI
type SkusClientAPI = original.SkusClientAPI
type TableClientAPI = original.TableClientAPI
type TableServicesClientAPI = original.TableServicesClientAPI
type UsagesClientAPI = original.UsagesClientAPI
