package iotcentral

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.
//
// Code generated by Microsoft (R) AutoRest Code Generator.
// Changes may cause incorrect behavior and will be lost if the code is regenerated.

// AppSku enumerates the values for app sku.
type AppSku string

const (
	// AppSkuST0 ...
	AppSkuST0 AppSku = "ST0"
	// AppSkuST1 ...
	AppSkuST1 AppSku = "ST1"
	// AppSkuST2 ...
	AppSkuST2 AppSku = "ST2"
)

// PossibleAppSkuValues returns an array of possible values for the AppSku const type.
func PossibleAppSkuValues() []AppSku {
	return []AppSku{AppSkuST0, AppSkuST1, AppSkuST2}
}

// AppState enumerates the values for app state.
type AppState string

const (
	// AppStateCreated ...
	AppStateCreated AppState = "created"
	// AppStateSuspended ...
	AppStateSuspended AppState = "suspended"
)

// PossibleAppStateValues returns an array of possible values for the AppState const type.
func PossibleAppStateValues() []AppState {
	return []AppState{AppStateCreated, AppStateSuspended}
}

// SystemAssignedServiceIdentityType enumerates the values for system assigned service identity type.
type SystemAssignedServiceIdentityType string

const (
	// SystemAssignedServiceIdentityTypeNone ...
	SystemAssignedServiceIdentityTypeNone SystemAssignedServiceIdentityType = "None"
	// SystemAssignedServiceIdentityTypeSystemAssigned ...
	SystemAssignedServiceIdentityTypeSystemAssigned SystemAssignedServiceIdentityType = "SystemAssigned"
)

// PossibleSystemAssignedServiceIdentityTypeValues returns an array of possible values for the SystemAssignedServiceIdentityType const type.
func PossibleSystemAssignedServiceIdentityTypeValues() []SystemAssignedServiceIdentityType {
	return []SystemAssignedServiceIdentityType{SystemAssignedServiceIdentityTypeNone, SystemAssignedServiceIdentityTypeSystemAssigned}
}
