//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package redisenterpriseapi

import original "github.com/Azure/azure-sdk-for-go/services/redisenterprise/mgmt/2022-01-01/redisenterprise/redisenterpriseapi"

type ClientAPI = original.ClientAPI
type DatabasesClientAPI = original.DatabasesClientAPI
type OperationsClientAPI = original.OperationsClientAPI
type OperationsStatusClientAPI = original.OperationsStatusClientAPI
type PrivateEndpointConnectionsClientAPI = original.PrivateEndpointConnectionsClientAPI
type PrivateLinkResourcesClientAPI = original.PrivateLinkResourcesClientAPI
