//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package artifactsapi

import original "github.com/Azure/azure-sdk-for-go/services/preview/synapse/2019-06-01-preview/artifacts/artifactsapi"

type BigDataPoolsClientAPI = original.BigDataPoolsClientAPI
type DataFlowClientAPI = original.DataFlowClientAPI
type DataFlowDebugSessionClientAPI = original.DataFlowDebugSessionClientAPI
type DatasetClientAPI = original.DatasetClientAPI
type IntegrationRuntimesClientAPI = original.IntegrationRuntimesClientAPI
type LinkedServiceClientAPI = original.LinkedServiceClientAPI
type NotebookClientAPI = original.NotebookClientAPI
type PipelineClientAPI = original.PipelineClientAPI
type PipelineRunClientAPI = original.PipelineRunClientAPI
type SQLPoolsClientAPI = original.SQLPoolsClientAPI
type SQLScriptClientAPI = original.SQLScriptClientAPI
type SparkJobDefinitionClientAPI = original.SparkJobDefinitionClientAPI
type TriggerClientAPI = original.TriggerClientAPI
type TriggerRunClientAPI = original.TriggerRunClientAPI
type WorkspaceClientAPI = original.WorkspaceClientAPI
type WorkspaceGitRepoManagementClientAPI = original.WorkspaceGitRepoManagementClientAPI
