//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package devspacesapi

import original "github.com/Azure/azure-sdk-for-go/services/devspaces/mgmt/2019-04-01/devspaces/devspacesapi"

type ContainerHostMappingsClientAPI = original.ContainerHostMappingsClientAPI
type ControllersClientAPI = original.ControllersClientAPI
type OperationsClientAPI = original.OperationsClientAPI
