//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package webpubsubapi

import original "github.com/Azure/azure-sdk-for-go/services/webpubsub/mgmt/2021-10-01/webpubsub/webpubsubapi"

type ClientAPI = original.ClientAPI
type HubsClientAPI = original.HubsClientAPI
type OperationsClientAPI = original.OperationsClientAPI
type PrivateEndpointConnectionsClientAPI = original.PrivateEndpointConnectionsClientAPI
type PrivateLinkResourcesClientAPI = original.PrivateLinkResourcesClientAPI
type SharedPrivateLinkResourcesClientAPI = original.SharedPrivateLinkResourcesClientAPI
type UsagesClientAPI = original.UsagesClientAPI
