//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package consumptionapi

import original "github.com/Azure/azure-sdk-for-go/services/consumption/mgmt/2019-10-01/consumption/consumptionapi"

type AggregatedCostClientAPI = original.AggregatedCostClientAPI
type BalancesClientAPI = original.BalancesClientAPI
type BudgetsClientAPI = original.BudgetsClientAPI
type ChargesClientAPI = original.ChargesClientAPI
type CreditsClientAPI = original.CreditsClientAPI
type EventsClientAPI = original.EventsClientAPI
type ForecastsClientAPI = original.ForecastsClientAPI
type LotsClientAPI = original.LotsClientAPI
type MarketplacesClientAPI = original.MarketplacesClientAPI
type OperationsClientAPI = original.OperationsClientAPI
type PriceSheetClientAPI = original.PriceSheetClientAPI
type ReservationRecommendationDetailsClientAPI = original.ReservationRecommendationDetailsClientAPI
type ReservationRecommendationsClientAPI = original.ReservationRecommendationsClientAPI
type ReservationTransactionsClientAPI = original.ReservationTransactionsClientAPI
type ReservationsDetailsClientAPI = original.ReservationsDetailsClientAPI
type ReservationsSummariesClientAPI = original.ReservationsSummariesClientAPI
type TagsClientAPI = original.TagsClientAPI
type UsageDetailsClientAPI = original.UsageDetailsClientAPI
