//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package documentdbapi

import original "github.com/Azure/azure-sdk-for-go/services/cosmos-db/mgmt/2022-08-15/documentdb/documentdbapi"

type CassandraClustersClientAPI = original.CassandraClustersClientAPI
type CassandraDataCentersClientAPI = original.CassandraDataCentersClientAPI
type CassandraResourcesClientAPI = original.CassandraResourcesClientAPI
type CollectionClientAPI = original.CollectionClientAPI
type CollectionPartitionClientAPI = original.CollectionPartitionClientAPI
type CollectionPartitionRegionClientAPI = original.CollectionPartitionRegionClientAPI
type CollectionRegionClientAPI = original.CollectionRegionClientAPI
type DatabaseAccountRegionClientAPI = original.DatabaseAccountRegionClientAPI
type DatabaseAccountsClientAPI = original.DatabaseAccountsClientAPI
type DatabaseClientAPI = original.DatabaseClientAPI
type GremlinResourcesClientAPI = original.GremlinResourcesClientAPI
type LocationsClientAPI = original.LocationsClientAPI
type MongoDBResourcesClientAPI = original.MongoDBResourcesClientAPI
type NotebookWorkspacesClientAPI = original.NotebookWorkspacesClientAPI
type OperationsClientAPI = original.OperationsClientAPI
type PartitionKeyRangeIDClientAPI = original.PartitionKeyRangeIDClientAPI
type PartitionKeyRangeIDRegionClientAPI = original.PartitionKeyRangeIDRegionClientAPI
type PercentileClientAPI = original.PercentileClientAPI
type PercentileSourceTargetClientAPI = original.PercentileSourceTargetClientAPI
type PercentileTargetClientAPI = original.PercentileTargetClientAPI
type PrivateEndpointConnectionsClientAPI = original.PrivateEndpointConnectionsClientAPI
type PrivateLinkResourcesClientAPI = original.PrivateLinkResourcesClientAPI
type RestorableDatabaseAccountsClientAPI = original.RestorableDatabaseAccountsClientAPI
type RestorableMongodbCollectionsClientAPI = original.RestorableMongodbCollectionsClientAPI
type RestorableMongodbDatabasesClientAPI = original.RestorableMongodbDatabasesClientAPI
type RestorableMongodbResourcesClientAPI = original.RestorableMongodbResourcesClientAPI
type RestorableSQLContainersClientAPI = original.RestorableSQLContainersClientAPI
type RestorableSQLDatabasesClientAPI = original.RestorableSQLDatabasesClientAPI
type RestorableSQLResourcesClientAPI = original.RestorableSQLResourcesClientAPI
type SQLResourcesClientAPI = original.SQLResourcesClientAPI
type ServiceClientAPI = original.ServiceClientAPI
type TableResourcesClientAPI = original.TableResourcesClientAPI
