//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package elasticapi

import original "github.com/Azure/azure-sdk-for-go/services/elastic/mgmt/2020-07-01/elastic/elasticapi"

type DeploymentInfoClientAPI = original.DeploymentInfoClientAPI
type MonitoredResourcesClientAPI = original.MonitoredResourcesClientAPI
type MonitorsClientAPI = original.MonitorsClientAPI
type OperationsClientAPI = original.OperationsClientAPI
type TagRulesClientAPI = original.TagRulesClientAPI
type VMCollectionClientAPI = original.VMCollectionClientAPI
type VMHostClientAPI = original.VMHostClientAPI
type VMIngestionClientAPI = original.VMIngestionClientAPI
