//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package computeapi

import original "github.com/Azure/azure-sdk-for-go/services/compute/mgmt/2022-08-01/compute/computeapi"

type AvailabilitySetsClientAPI = original.AvailabilitySetsClientAPI
type CapacityReservationGroupsClientAPI = original.CapacityReservationGroupsClientAPI
type CapacityReservationsClientAPI = original.CapacityReservationsClientAPI
type CloudServiceOperatingSystemsClientAPI = original.CloudServiceOperatingSystemsClientAPI
type CloudServiceRoleInstancesClientAPI = original.CloudServiceRoleInstancesClientAPI
type CloudServiceRolesClientAPI = original.CloudServiceRolesClientAPI
type CloudServicesClientAPI = original.CloudServicesClientAPI
type CloudServicesUpdateDomainClientAPI = original.CloudServicesUpdateDomainClientAPI
type CommunityGalleriesClientAPI = original.CommunityGalleriesClientAPI
type CommunityGalleryImageVersionsClientAPI = original.CommunityGalleryImageVersionsClientAPI
type CommunityGalleryImagesClientAPI = original.CommunityGalleryImagesClientAPI
type DedicatedHostGroupsClientAPI = original.DedicatedHostGroupsClientAPI
type DedicatedHostsClientAPI = original.DedicatedHostsClientAPI
type DiskAccessesClientAPI = original.DiskAccessesClientAPI
type DiskEncryptionSetsClientAPI = original.DiskEncryptionSetsClientAPI
type DiskRestorePointClientAPI = original.DiskRestorePointClientAPI
type DisksClientAPI = original.DisksClientAPI
type GalleriesClientAPI = original.GalleriesClientAPI
type GalleryApplicationVersionsClientAPI = original.GalleryApplicationVersionsClientAPI
type GalleryApplicationsClientAPI = original.GalleryApplicationsClientAPI
type GalleryImageVersionsClientAPI = original.GalleryImageVersionsClientAPI
type GalleryImagesClientAPI = original.GalleryImagesClientAPI
type GallerySharingProfileClientAPI = original.GallerySharingProfileClientAPI
type ImagesClientAPI = original.ImagesClientAPI
type LogAnalyticsClientAPI = original.LogAnalyticsClientAPI
type OperationsClientAPI = original.OperationsClientAPI
type ProximityPlacementGroupsClientAPI = original.ProximityPlacementGroupsClientAPI
type ResourceSkusClientAPI = original.ResourceSkusClientAPI
type RestorePointCollectionsClientAPI = original.RestorePointCollectionsClientAPI
type RestorePointsClientAPI = original.RestorePointsClientAPI
type SSHPublicKeysClientAPI = original.SSHPublicKeysClientAPI
type SharedGalleriesClientAPI = original.SharedGalleriesClientAPI
type SharedGalleryImageVersionsClientAPI = original.SharedGalleryImageVersionsClientAPI
type SharedGalleryImagesClientAPI = original.SharedGalleryImagesClientAPI
type SnapshotsClientAPI = original.SnapshotsClientAPI
type UsageClientAPI = original.UsageClientAPI
type VirtualMachineExtensionImagesClientAPI = original.VirtualMachineExtensionImagesClientAPI
type VirtualMachineExtensionsClientAPI = original.VirtualMachineExtensionsClientAPI
type VirtualMachineImagesClientAPI = original.VirtualMachineImagesClientAPI
type VirtualMachineImagesEdgeZoneClientAPI = original.VirtualMachineImagesEdgeZoneClientAPI
type VirtualMachineRunCommandsClientAPI = original.VirtualMachineRunCommandsClientAPI
type VirtualMachineScaleSetExtensionsClientAPI = original.VirtualMachineScaleSetExtensionsClientAPI
type VirtualMachineScaleSetRollingUpgradesClientAPI = original.VirtualMachineScaleSetRollingUpgradesClientAPI
type VirtualMachineScaleSetVMExtensionsClientAPI = original.VirtualMachineScaleSetVMExtensionsClientAPI
type VirtualMachineScaleSetVMRunCommandsClientAPI = original.VirtualMachineScaleSetVMRunCommandsClientAPI
type VirtualMachineScaleSetVMsClientAPI = original.VirtualMachineScaleSetVMsClientAPI
type VirtualMachineScaleSetsClientAPI = original.VirtualMachineScaleSetsClientAPI
type VirtualMachineSizesClientAPI = original.VirtualMachineSizesClientAPI
type VirtualMachinesClientAPI = original.VirtualMachinesClientAPI
