//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package postgresqlflexibleserversapi

import original "github.com/Azure/azure-sdk-for-go/services/postgresql/mgmt/2021-06-01/postgresqlflexibleservers/postgresqlflexibleserversapi"

type CheckNameAvailabilityClientAPI = original.CheckNameAvailabilityClientAPI
type ConfigurationsClientAPI = original.ConfigurationsClientAPI
type DatabasesClientAPI = original.DatabasesClientAPI
type FirewallRulesClientAPI = original.FirewallRulesClientAPI
type GetPrivateDNSZoneSuffixClientAPI = original.GetPrivateDNSZoneSuffixClientAPI
type LocationBasedCapabilitiesClientAPI = original.LocationBasedCapabilitiesClientAPI
type OperationsClientAPI = original.OperationsClientAPI
type ServersClientAPI = original.ServersClientAPI
type VirtualNetworkSubnetUsageClientAPI = original.VirtualNetworkSubnetUsageClientAPI
