// Deprecated: Please note, this package has been deprecated. A replacement package is available [github.com/Azure/azure-sdk-for-go/sdk/resourcemanager/automanage/armautomanage](https://pkg.go.dev/github.com/Azure/azure-sdk-for-go/sdk/resourcemanager/automanage/armautomanage). We strongly encourage you to upgrade to continue receiving updates. See [Migration Guide](https://aka.ms/azsdk/golang/t2/migration) for guidance on upgrading. Refer to our [deprecation policy](https://azure.github.io/azure-sdk/policies_support.html) for more details.
package automanageapi

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.
//
// Code generated by Microsoft (R) AutoRest Code Generator.
// Changes may cause incorrect behavior and will be lost if the code is regenerated.

import (
	"context"
	"github.com/Azure/azure-sdk-for-go/services/preview/automanage/mgmt/2020-06-30-preview/automanage"
	"github.com/Azure/go-autorest/autorest"
)

// AccountsClientAPI contains the set of methods on the AccountsClient type.
type AccountsClientAPI interface {
	CreateOrUpdate(ctx context.Context, accountName string, resourceGroupName string, parameters automanage.Account) (result automanage.Account, err error)
	Delete(ctx context.Context, resourceGroupName string, accountName string) (result autorest.Response, err error)
	Get(ctx context.Context, accountName string, resourceGroupName string) (result automanage.Account, err error)
	ListByResourceGroup(ctx context.Context, resourceGroupName string) (result automanage.AccountList, err error)
	ListBySubscription(ctx context.Context) (result automanage.AccountList, err error)
	Update(ctx context.Context, accountName string, resourceGroupName string, parameters automanage.AccountUpdate) (result automanage.Account, err error)
}

var _ AccountsClientAPI = (*automanage.AccountsClient)(nil)

// ConfigurationProfileAssignmentsClientAPI contains the set of methods on the ConfigurationProfileAssignmentsClient type.
type ConfigurationProfileAssignmentsClientAPI interface {
	CreateOrUpdate(ctx context.Context, configurationProfileAssignmentName string, parameters automanage.ConfigurationProfileAssignment, resourceGroupName string, VMName string) (result automanage.ConfigurationProfileAssignmentsCreateOrUpdateFuture, err error)
	Delete(ctx context.Context, resourceGroupName string, configurationProfileAssignmentName string, VMName string) (result autorest.Response, err error)
	Get(ctx context.Context, resourceGroupName string, configurationProfileAssignmentName string, VMName string) (result automanage.ConfigurationProfileAssignment, err error)
	List(ctx context.Context, resourceGroupName string) (result automanage.ConfigurationProfileAssignmentList, err error)
	ListBySubscription(ctx context.Context) (result automanage.ConfigurationProfileAssignmentList, err error)
}

var _ ConfigurationProfileAssignmentsClientAPI = (*automanage.ConfigurationProfileAssignmentsClient)(nil)

// ConfigurationProfilePreferencesClientAPI contains the set of methods on the ConfigurationProfilePreferencesClient type.
type ConfigurationProfilePreferencesClientAPI interface {
	CreateOrUpdate(ctx context.Context, configurationProfilePreferenceName string, resourceGroupName string, parameters automanage.ConfigurationProfilePreference) (result automanage.ConfigurationProfilePreference, err error)
	Delete(ctx context.Context, resourceGroupName string, configurationProfilePreferenceName string) (result autorest.Response, err error)
	Get(ctx context.Context, configurationProfilePreferenceName string, resourceGroupName string) (result automanage.ConfigurationProfilePreference, err error)
	ListByResourceGroup(ctx context.Context, resourceGroupName string) (result automanage.ConfigurationProfilePreferenceList, err error)
	ListBySubscription(ctx context.Context) (result automanage.ConfigurationProfilePreferenceList, err error)
	Update(ctx context.Context, configurationProfilePreferenceName string, resourceGroupName string, parameters automanage.ConfigurationProfilePreferenceUpdate) (result automanage.ConfigurationProfilePreference, err error)
}

var _ ConfigurationProfilePreferencesClientAPI = (*automanage.ConfigurationProfilePreferencesClient)(nil)

// OperationsClientAPI contains the set of methods on the OperationsClient type.
type OperationsClientAPI interface {
	List(ctx context.Context) (result automanage.OperationList, err error)
}

var _ OperationsClientAPI = (*automanage.OperationsClient)(nil)
