//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package redisapi

import original "github.com/Azure/azure-sdk-for-go/services/redis/mgmt/2021-06-01/redis/redisapi"

type AsyncOperationStatusClientAPI = original.AsyncOperationStatusClientAPI
type ClientAPI = original.ClientAPI
type FirewallRulesClientAPI = original.FirewallRulesClientAPI
type LinkedServerClientAPI = original.LinkedServerClientAPI
type OperationsClientAPI = original.OperationsClientAPI
type PatchSchedulesClientAPI = original.PatchSchedulesClientAPI
type PrivateEndpointConnectionsClientAPI = original.PrivateEndpointConnectionsClientAPI
type PrivateLinkResourcesClientAPI = original.PrivateLinkResourcesClientAPI
