//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package sql

import (
	"context"

	original "github.com/Azure/azure-sdk-for-go/services/preview/sql/mgmt/2018-06-01-preview/sql"
)

const (
	DefaultBaseURI = original.DefaultBaseURI
)

type CatalogCollationType = original.CatalogCollationType

const (
	DATABASEDEFAULT         CatalogCollationType = original.DATABASEDEFAULT
	SQLLatin1GeneralCP1CIAS CatalogCollationType = original.SQLLatin1GeneralCP1CIAS
)

type DatabaseState = original.DatabaseState

const (
	All     DatabaseState = original.All
	Deleted DatabaseState = original.Deleted
	Live    DatabaseState = original.Live
)

type IdentityType = original.IdentityType

const (
	SystemAssigned IdentityType = original.SystemAssigned
)

type InstancePoolLicenseType = original.InstancePoolLicenseType

const (
	BasePrice       InstancePoolLicenseType = original.BasePrice
	LicenseIncluded InstancePoolLicenseType = original.LicenseIncluded
)

type ManagedDatabaseCreateMode = original.ManagedDatabaseCreateMode

const (
	Default                        ManagedDatabaseCreateMode = original.Default
	PointInTimeRestore             ManagedDatabaseCreateMode = original.PointInTimeRestore
	Recovery                       ManagedDatabaseCreateMode = original.Recovery
	RestoreExternalBackup          ManagedDatabaseCreateMode = original.RestoreExternalBackup
	RestoreLongTermRetentionBackup ManagedDatabaseCreateMode = original.RestoreLongTermRetentionBackup
)

type ManagedDatabaseStatus = original.ManagedDatabaseStatus

const (
	Creating     ManagedDatabaseStatus = original.Creating
	Inaccessible ManagedDatabaseStatus = original.Inaccessible
	Offline      ManagedDatabaseStatus = original.Offline
	Online       ManagedDatabaseStatus = original.Online
	Restoring    ManagedDatabaseStatus = original.Restoring
	Shutdown     ManagedDatabaseStatus = original.Shutdown
	Updating     ManagedDatabaseStatus = original.Updating
)

type ManagedInstanceLicenseType = original.ManagedInstanceLicenseType

const (
	ManagedInstanceLicenseTypeBasePrice       ManagedInstanceLicenseType = original.ManagedInstanceLicenseTypeBasePrice
	ManagedInstanceLicenseTypeLicenseIncluded ManagedInstanceLicenseType = original.ManagedInstanceLicenseTypeLicenseIncluded
)

type ManagedInstanceProxyOverride = original.ManagedInstanceProxyOverride

const (
	ManagedInstanceProxyOverrideDefault  ManagedInstanceProxyOverride = original.ManagedInstanceProxyOverrideDefault
	ManagedInstanceProxyOverrideProxy    ManagedInstanceProxyOverride = original.ManagedInstanceProxyOverrideProxy
	ManagedInstanceProxyOverrideRedirect ManagedInstanceProxyOverride = original.ManagedInstanceProxyOverrideRedirect
)

type ManagedServerCreateMode = original.ManagedServerCreateMode

const (
	ManagedServerCreateModeDefault            ManagedServerCreateMode = original.ManagedServerCreateModeDefault
	ManagedServerCreateModePointInTimeRestore ManagedServerCreateMode = original.ManagedServerCreateModePointInTimeRestore
)

type ManagementOperationState = original.ManagementOperationState

const (
	CancelInProgress ManagementOperationState = original.CancelInProgress
	Cancelled        ManagementOperationState = original.Cancelled
	Failed           ManagementOperationState = original.Failed
	InProgress       ManagementOperationState = original.InProgress
	Pending          ManagementOperationState = original.Pending
	Succeeded        ManagementOperationState = original.Succeeded
)

type ReplicaType = original.ReplicaType

const (
	Primary           ReplicaType = original.Primary
	ReadableSecondary ReplicaType = original.ReadableSecondary
)

type SecurityAlertPolicyState = original.SecurityAlertPolicyState

const (
	SecurityAlertPolicyStateDisabled SecurityAlertPolicyState = original.SecurityAlertPolicyStateDisabled
	SecurityAlertPolicyStateEnabled  SecurityAlertPolicyState = original.SecurityAlertPolicyStateEnabled
	SecurityAlertPolicyStateNew      SecurityAlertPolicyState = original.SecurityAlertPolicyStateNew
)

type SensitivityLabelRank = original.SensitivityLabelRank

const (
	Critical SensitivityLabelRank = original.Critical
	High     SensitivityLabelRank = original.High
	Low      SensitivityLabelRank = original.Low
	Medium   SensitivityLabelRank = original.Medium
	None     SensitivityLabelRank = original.None
)

type SensitivityLabelSource = original.SensitivityLabelSource

const (
	Current     SensitivityLabelSource = original.Current
	Recommended SensitivityLabelSource = original.Recommended
)

type Status = original.Status

const (
	StatusCanceled   Status = original.StatusCanceled
	StatusCompleted  Status = original.StatusCompleted
	StatusFailed     Status = original.StatusFailed
	StatusInProgress Status = original.StatusInProgress
	StatusNotStarted Status = original.StatusNotStarted
	StatusSlowedDown Status = original.StatusSlowedDown
)

type AdministratorListResult = original.AdministratorListResult
type AdministratorListResultIterator = original.AdministratorListResultIterator
type AdministratorListResultPage = original.AdministratorListResultPage
type AdministratorProperties = original.AdministratorProperties
type BaseClient = original.BaseClient
type BaseLongTermRetentionPolicyProperties = original.BaseLongTermRetentionPolicyProperties
type CompleteDatabaseRestoreDefinition = original.CompleteDatabaseRestoreDefinition
type DatabaseSecurityAlertListResult = original.DatabaseSecurityAlertListResult
type DatabaseSecurityAlertListResultIterator = original.DatabaseSecurityAlertListResultIterator
type DatabaseSecurityAlertListResultPage = original.DatabaseSecurityAlertListResultPage
type DatabaseSecurityAlertPoliciesClient = original.DatabaseSecurityAlertPoliciesClient
type DatabaseSecurityAlertPolicy = original.DatabaseSecurityAlertPolicy
type DatabasesClient = original.DatabasesClient
type DatabasesFailoverFuture = original.DatabasesFailoverFuture
type ElasticPoolsClient = original.ElasticPoolsClient
type ElasticPoolsFailoverFuture = original.ElasticPoolsFailoverFuture
type InstancePool = original.InstancePool
type InstancePoolListResult = original.InstancePoolListResult
type InstancePoolListResultIterator = original.InstancePoolListResultIterator
type InstancePoolListResultPage = original.InstancePoolListResultPage
type InstancePoolProperties = original.InstancePoolProperties
type InstancePoolUpdate = original.InstancePoolUpdate
type InstancePoolsClient = original.InstancePoolsClient
type InstancePoolsCreateOrUpdateFuture = original.InstancePoolsCreateOrUpdateFuture
type InstancePoolsDeleteFuture = original.InstancePoolsDeleteFuture
type InstancePoolsUpdateFuture = original.InstancePoolsUpdateFuture
type LongTermRetentionManagedInstanceBackupsClient = original.LongTermRetentionManagedInstanceBackupsClient
type LongTermRetentionManagedInstanceBackupsDeleteByResourceGroupFuture = original.LongTermRetentionManagedInstanceBackupsDeleteByResourceGroupFuture
type LongTermRetentionManagedInstanceBackupsDeleteFuture = original.LongTermRetentionManagedInstanceBackupsDeleteFuture
type ManagedDatabase = original.ManagedDatabase
type ManagedDatabaseListResult = original.ManagedDatabaseListResult
type ManagedDatabaseListResultIterator = original.ManagedDatabaseListResultIterator
type ManagedDatabaseListResultPage = original.ManagedDatabaseListResultPage
type ManagedDatabaseProperties = original.ManagedDatabaseProperties
type ManagedDatabaseRestoreDetailsClient = original.ManagedDatabaseRestoreDetailsClient
type ManagedDatabaseRestoreDetailsProperties = original.ManagedDatabaseRestoreDetailsProperties
type ManagedDatabaseRestoreDetailsResult = original.ManagedDatabaseRestoreDetailsResult
type ManagedDatabaseSensitivityLabelsClient = original.ManagedDatabaseSensitivityLabelsClient
type ManagedDatabaseUpdate = original.ManagedDatabaseUpdate
type ManagedDatabasesClient = original.ManagedDatabasesClient
type ManagedDatabasesCompleteRestoreFuture = original.ManagedDatabasesCompleteRestoreFuture
type ManagedDatabasesCreateOrUpdateFuture = original.ManagedDatabasesCreateOrUpdateFuture
type ManagedDatabasesDeleteFuture = original.ManagedDatabasesDeleteFuture
type ManagedDatabasesUpdateFuture = original.ManagedDatabasesUpdateFuture
type ManagedInstance = original.ManagedInstance
type ManagedInstanceListResult = original.ManagedInstanceListResult
type ManagedInstanceListResultIterator = original.ManagedInstanceListResultIterator
type ManagedInstanceListResultPage = original.ManagedInstanceListResultPage
type ManagedInstanceLongTermRetentionBackup = original.ManagedInstanceLongTermRetentionBackup
type ManagedInstanceLongTermRetentionBackupListResult = original.ManagedInstanceLongTermRetentionBackupListResult
type ManagedInstanceLongTermRetentionBackupListResultIterator = original.ManagedInstanceLongTermRetentionBackupListResultIterator
type ManagedInstanceLongTermRetentionBackupListResultPage = original.ManagedInstanceLongTermRetentionBackupListResultPage
type ManagedInstanceLongTermRetentionBackupProperties = original.ManagedInstanceLongTermRetentionBackupProperties
type ManagedInstanceLongTermRetentionPoliciesClient = original.ManagedInstanceLongTermRetentionPoliciesClient
type ManagedInstanceLongTermRetentionPoliciesCreateOrUpdateFuture = original.ManagedInstanceLongTermRetentionPoliciesCreateOrUpdateFuture
type ManagedInstanceLongTermRetentionPolicy = original.ManagedInstanceLongTermRetentionPolicy
type ManagedInstanceLongTermRetentionPolicyListResult = original.ManagedInstanceLongTermRetentionPolicyListResult
type ManagedInstanceLongTermRetentionPolicyListResultIterator = original.ManagedInstanceLongTermRetentionPolicyListResultIterator
type ManagedInstanceLongTermRetentionPolicyListResultPage = original.ManagedInstanceLongTermRetentionPolicyListResultPage
type ManagedInstanceOperation = original.ManagedInstanceOperation
type ManagedInstanceOperationListResult = original.ManagedInstanceOperationListResult
type ManagedInstanceOperationListResultIterator = original.ManagedInstanceOperationListResultIterator
type ManagedInstanceOperationListResultPage = original.ManagedInstanceOperationListResultPage
type ManagedInstanceOperationParametersPair = original.ManagedInstanceOperationParametersPair
type ManagedInstanceOperationProperties = original.ManagedInstanceOperationProperties
type ManagedInstanceOperationSteps = original.ManagedInstanceOperationSteps
type ManagedInstanceOperationsClient = original.ManagedInstanceOperationsClient
type ManagedInstanceProperties = original.ManagedInstanceProperties
type ManagedInstanceUpdate = original.ManagedInstanceUpdate
type ManagedInstanceVulnerabilityAssessment = original.ManagedInstanceVulnerabilityAssessment
type ManagedInstanceVulnerabilityAssessmentListResult = original.ManagedInstanceVulnerabilityAssessmentListResult
type ManagedInstanceVulnerabilityAssessmentListResultIterator = original.ManagedInstanceVulnerabilityAssessmentListResultIterator
type ManagedInstanceVulnerabilityAssessmentListResultPage = original.ManagedInstanceVulnerabilityAssessmentListResultPage
type ManagedInstanceVulnerabilityAssessmentProperties = original.ManagedInstanceVulnerabilityAssessmentProperties
type ManagedInstanceVulnerabilityAssessmentsClient = original.ManagedInstanceVulnerabilityAssessmentsClient
type ManagedInstancesClient = original.ManagedInstancesClient
type ManagedInstancesCreateOrUpdateFuture = original.ManagedInstancesCreateOrUpdateFuture
type ManagedInstancesDeleteFuture = original.ManagedInstancesDeleteFuture
type ManagedInstancesUpdateFuture = original.ManagedInstancesUpdateFuture
type Name = original.Name
type PrivateEndpointConnection = original.PrivateEndpointConnection
type PrivateEndpointConnectionListResult = original.PrivateEndpointConnectionListResult
type PrivateEndpointConnectionListResultIterator = original.PrivateEndpointConnectionListResultIterator
type PrivateEndpointConnectionListResultPage = original.PrivateEndpointConnectionListResultPage
type PrivateEndpointConnectionProperties = original.PrivateEndpointConnectionProperties
type PrivateEndpointConnectionsClient = original.PrivateEndpointConnectionsClient
type PrivateEndpointConnectionsCreateOrUpdateFuture = original.PrivateEndpointConnectionsCreateOrUpdateFuture
type PrivateEndpointConnectionsDeleteFuture = original.PrivateEndpointConnectionsDeleteFuture
type PrivateEndpointProperty = original.PrivateEndpointProperty
type PrivateLinkServiceConnectionStateProperty = original.PrivateLinkServiceConnectionStateProperty
type ProxyResource = original.ProxyResource
type Resource = original.Resource
type ResourceIdentity = original.ResourceIdentity
type SecurityAlertPolicyProperties = original.SecurityAlertPolicyProperties
type SensitivityLabel = original.SensitivityLabel
type SensitivityLabelListResult = original.SensitivityLabelListResult
type SensitivityLabelListResultIterator = original.SensitivityLabelListResultIterator
type SensitivityLabelListResultPage = original.SensitivityLabelListResultPage
type SensitivityLabelProperties = original.SensitivityLabelProperties
type ServerAzureADAdministrator = original.ServerAzureADAdministrator
type ServerAzureADAdministratorsClient = original.ServerAzureADAdministratorsClient
type ServerAzureADAdministratorsCreateOrUpdateFuture = original.ServerAzureADAdministratorsCreateOrUpdateFuture
type ServerAzureADAdministratorsDeleteFuture = original.ServerAzureADAdministratorsDeleteFuture
type ServerVulnerabilityAssessment = original.ServerVulnerabilityAssessment
type ServerVulnerabilityAssessmentListResult = original.ServerVulnerabilityAssessmentListResult
type ServerVulnerabilityAssessmentListResultIterator = original.ServerVulnerabilityAssessmentListResultIterator
type ServerVulnerabilityAssessmentListResultPage = original.ServerVulnerabilityAssessmentListResultPage
type ServerVulnerabilityAssessmentProperties = original.ServerVulnerabilityAssessmentProperties
type ServerVulnerabilityAssessmentsClient = original.ServerVulnerabilityAssessmentsClient
type Sku = original.Sku
type TrackedResource = original.TrackedResource
type UpsertManagedServerOperationParameters = original.UpsertManagedServerOperationParameters
type UpsertManagedServerOperationStep = original.UpsertManagedServerOperationStep
type Usage = original.Usage
type UsageListResult = original.UsageListResult
type UsageListResultIterator = original.UsageListResultIterator
type UsageListResultPage = original.UsageListResultPage
type UsagesClient = original.UsagesClient
type VulnerabilityAssessmentRecurringScansProperties = original.VulnerabilityAssessmentRecurringScansProperties

func New(subscriptionID string) BaseClient {
	return original.New(subscriptionID)
}
func NewAdministratorListResultIterator(page AdministratorListResultPage) AdministratorListResultIterator {
	return original.NewAdministratorListResultIterator(page)
}
func NewAdministratorListResultPage(cur AdministratorListResult, getNextPage func(context.Context, AdministratorListResult) (AdministratorListResult, error)) AdministratorListResultPage {
	return original.NewAdministratorListResultPage(cur, getNextPage)
}
func NewDatabaseSecurityAlertListResultIterator(page DatabaseSecurityAlertListResultPage) DatabaseSecurityAlertListResultIterator {
	return original.NewDatabaseSecurityAlertListResultIterator(page)
}
func NewDatabaseSecurityAlertListResultPage(cur DatabaseSecurityAlertListResult, getNextPage func(context.Context, DatabaseSecurityAlertListResult) (DatabaseSecurityAlertListResult, error)) DatabaseSecurityAlertListResultPage {
	return original.NewDatabaseSecurityAlertListResultPage(cur, getNextPage)
}
func NewDatabaseSecurityAlertPoliciesClient(subscriptionID string) DatabaseSecurityAlertPoliciesClient {
	return original.NewDatabaseSecurityAlertPoliciesClient(subscriptionID)
}
func NewDatabaseSecurityAlertPoliciesClientWithBaseURI(baseURI string, subscriptionID string) DatabaseSecurityAlertPoliciesClient {
	return original.NewDatabaseSecurityAlertPoliciesClientWithBaseURI(baseURI, subscriptionID)
}
func NewDatabasesClient(subscriptionID string) DatabasesClient {
	return original.NewDatabasesClient(subscriptionID)
}
func NewDatabasesClientWithBaseURI(baseURI string, subscriptionID string) DatabasesClient {
	return original.NewDatabasesClientWithBaseURI(baseURI, subscriptionID)
}
func NewElasticPoolsClient(subscriptionID string) ElasticPoolsClient {
	return original.NewElasticPoolsClient(subscriptionID)
}
func NewElasticPoolsClientWithBaseURI(baseURI string, subscriptionID string) ElasticPoolsClient {
	return original.NewElasticPoolsClientWithBaseURI(baseURI, subscriptionID)
}
func NewInstancePoolListResultIterator(page InstancePoolListResultPage) InstancePoolListResultIterator {
	return original.NewInstancePoolListResultIterator(page)
}
func NewInstancePoolListResultPage(cur InstancePoolListResult, getNextPage func(context.Context, InstancePoolListResult) (InstancePoolListResult, error)) InstancePoolListResultPage {
	return original.NewInstancePoolListResultPage(cur, getNextPage)
}
func NewInstancePoolsClient(subscriptionID string) InstancePoolsClient {
	return original.NewInstancePoolsClient(subscriptionID)
}
func NewInstancePoolsClientWithBaseURI(baseURI string, subscriptionID string) InstancePoolsClient {
	return original.NewInstancePoolsClientWithBaseURI(baseURI, subscriptionID)
}
func NewLongTermRetentionManagedInstanceBackupsClient(subscriptionID string) LongTermRetentionManagedInstanceBackupsClient {
	return original.NewLongTermRetentionManagedInstanceBackupsClient(subscriptionID)
}
func NewLongTermRetentionManagedInstanceBackupsClientWithBaseURI(baseURI string, subscriptionID string) LongTermRetentionManagedInstanceBackupsClient {
	return original.NewLongTermRetentionManagedInstanceBackupsClientWithBaseURI(baseURI, subscriptionID)
}
func NewManagedDatabaseListResultIterator(page ManagedDatabaseListResultPage) ManagedDatabaseListResultIterator {
	return original.NewManagedDatabaseListResultIterator(page)
}
func NewManagedDatabaseListResultPage(cur ManagedDatabaseListResult, getNextPage func(context.Context, ManagedDatabaseListResult) (ManagedDatabaseListResult, error)) ManagedDatabaseListResultPage {
	return original.NewManagedDatabaseListResultPage(cur, getNextPage)
}
func NewManagedDatabaseRestoreDetailsClient(subscriptionID string) ManagedDatabaseRestoreDetailsClient {
	return original.NewManagedDatabaseRestoreDetailsClient(subscriptionID)
}
func NewManagedDatabaseRestoreDetailsClientWithBaseURI(baseURI string, subscriptionID string) ManagedDatabaseRestoreDetailsClient {
	return original.NewManagedDatabaseRestoreDetailsClientWithBaseURI(baseURI, subscriptionID)
}
func NewManagedDatabaseSensitivityLabelsClient(subscriptionID string) ManagedDatabaseSensitivityLabelsClient {
	return original.NewManagedDatabaseSensitivityLabelsClient(subscriptionID)
}
func NewManagedDatabaseSensitivityLabelsClientWithBaseURI(baseURI string, subscriptionID string) ManagedDatabaseSensitivityLabelsClient {
	return original.NewManagedDatabaseSensitivityLabelsClientWithBaseURI(baseURI, subscriptionID)
}
func NewManagedDatabasesClient(subscriptionID string) ManagedDatabasesClient {
	return original.NewManagedDatabasesClient(subscriptionID)
}
func NewManagedDatabasesClientWithBaseURI(baseURI string, subscriptionID string) ManagedDatabasesClient {
	return original.NewManagedDatabasesClientWithBaseURI(baseURI, subscriptionID)
}
func NewManagedInstanceListResultIterator(page ManagedInstanceListResultPage) ManagedInstanceListResultIterator {
	return original.NewManagedInstanceListResultIterator(page)
}
func NewManagedInstanceListResultPage(cur ManagedInstanceListResult, getNextPage func(context.Context, ManagedInstanceListResult) (ManagedInstanceListResult, error)) ManagedInstanceListResultPage {
	return original.NewManagedInstanceListResultPage(cur, getNextPage)
}
func NewManagedInstanceLongTermRetentionBackupListResultIterator(page ManagedInstanceLongTermRetentionBackupListResultPage) ManagedInstanceLongTermRetentionBackupListResultIterator {
	return original.NewManagedInstanceLongTermRetentionBackupListResultIterator(page)
}
func NewManagedInstanceLongTermRetentionBackupListResultPage(cur ManagedInstanceLongTermRetentionBackupListResult, getNextPage func(context.Context, ManagedInstanceLongTermRetentionBackupListResult) (ManagedInstanceLongTermRetentionBackupListResult, error)) ManagedInstanceLongTermRetentionBackupListResultPage {
	return original.NewManagedInstanceLongTermRetentionBackupListResultPage(cur, getNextPage)
}
func NewManagedInstanceLongTermRetentionPoliciesClient(subscriptionID string) ManagedInstanceLongTermRetentionPoliciesClient {
	return original.NewManagedInstanceLongTermRetentionPoliciesClient(subscriptionID)
}
func NewManagedInstanceLongTermRetentionPoliciesClientWithBaseURI(baseURI string, subscriptionID string) ManagedInstanceLongTermRetentionPoliciesClient {
	return original.NewManagedInstanceLongTermRetentionPoliciesClientWithBaseURI(baseURI, subscriptionID)
}
func NewManagedInstanceLongTermRetentionPolicyListResultIterator(page ManagedInstanceLongTermRetentionPolicyListResultPage) ManagedInstanceLongTermRetentionPolicyListResultIterator {
	return original.NewManagedInstanceLongTermRetentionPolicyListResultIterator(page)
}
func NewManagedInstanceLongTermRetentionPolicyListResultPage(cur ManagedInstanceLongTermRetentionPolicyListResult, getNextPage func(context.Context, ManagedInstanceLongTermRetentionPolicyListResult) (ManagedInstanceLongTermRetentionPolicyListResult, error)) ManagedInstanceLongTermRetentionPolicyListResultPage {
	return original.NewManagedInstanceLongTermRetentionPolicyListResultPage(cur, getNextPage)
}
func NewManagedInstanceOperationListResultIterator(page ManagedInstanceOperationListResultPage) ManagedInstanceOperationListResultIterator {
	return original.NewManagedInstanceOperationListResultIterator(page)
}
func NewManagedInstanceOperationListResultPage(cur ManagedInstanceOperationListResult, getNextPage func(context.Context, ManagedInstanceOperationListResult) (ManagedInstanceOperationListResult, error)) ManagedInstanceOperationListResultPage {
	return original.NewManagedInstanceOperationListResultPage(cur, getNextPage)
}
func NewManagedInstanceOperationsClient(subscriptionID string) ManagedInstanceOperationsClient {
	return original.NewManagedInstanceOperationsClient(subscriptionID)
}
func NewManagedInstanceOperationsClientWithBaseURI(baseURI string, subscriptionID string) ManagedInstanceOperationsClient {
	return original.NewManagedInstanceOperationsClientWithBaseURI(baseURI, subscriptionID)
}
func NewManagedInstanceVulnerabilityAssessmentListResultIterator(page ManagedInstanceVulnerabilityAssessmentListResultPage) ManagedInstanceVulnerabilityAssessmentListResultIterator {
	return original.NewManagedInstanceVulnerabilityAssessmentListResultIterator(page)
}
func NewManagedInstanceVulnerabilityAssessmentListResultPage(cur ManagedInstanceVulnerabilityAssessmentListResult, getNextPage func(context.Context, ManagedInstanceVulnerabilityAssessmentListResult) (ManagedInstanceVulnerabilityAssessmentListResult, error)) ManagedInstanceVulnerabilityAssessmentListResultPage {
	return original.NewManagedInstanceVulnerabilityAssessmentListResultPage(cur, getNextPage)
}
func NewManagedInstanceVulnerabilityAssessmentsClient(subscriptionID string) ManagedInstanceVulnerabilityAssessmentsClient {
	return original.NewManagedInstanceVulnerabilityAssessmentsClient(subscriptionID)
}
func NewManagedInstanceVulnerabilityAssessmentsClientWithBaseURI(baseURI string, subscriptionID string) ManagedInstanceVulnerabilityAssessmentsClient {
	return original.NewManagedInstanceVulnerabilityAssessmentsClientWithBaseURI(baseURI, subscriptionID)
}
func NewManagedInstancesClient(subscriptionID string) ManagedInstancesClient {
	return original.NewManagedInstancesClient(subscriptionID)
}
func NewManagedInstancesClientWithBaseURI(baseURI string, subscriptionID string) ManagedInstancesClient {
	return original.NewManagedInstancesClientWithBaseURI(baseURI, subscriptionID)
}
func NewPrivateEndpointConnectionListResultIterator(page PrivateEndpointConnectionListResultPage) PrivateEndpointConnectionListResultIterator {
	return original.NewPrivateEndpointConnectionListResultIterator(page)
}
func NewPrivateEndpointConnectionListResultPage(cur PrivateEndpointConnectionListResult, getNextPage func(context.Context, PrivateEndpointConnectionListResult) (PrivateEndpointConnectionListResult, error)) PrivateEndpointConnectionListResultPage {
	return original.NewPrivateEndpointConnectionListResultPage(cur, getNextPage)
}
func NewPrivateEndpointConnectionsClient(subscriptionID string) PrivateEndpointConnectionsClient {
	return original.NewPrivateEndpointConnectionsClient(subscriptionID)
}
func NewPrivateEndpointConnectionsClientWithBaseURI(baseURI string, subscriptionID string) PrivateEndpointConnectionsClient {
	return original.NewPrivateEndpointConnectionsClientWithBaseURI(baseURI, subscriptionID)
}
func NewSensitivityLabelListResultIterator(page SensitivityLabelListResultPage) SensitivityLabelListResultIterator {
	return original.NewSensitivityLabelListResultIterator(page)
}
func NewSensitivityLabelListResultPage(cur SensitivityLabelListResult, getNextPage func(context.Context, SensitivityLabelListResult) (SensitivityLabelListResult, error)) SensitivityLabelListResultPage {
	return original.NewSensitivityLabelListResultPage(cur, getNextPage)
}
func NewServerAzureADAdministratorsClient(subscriptionID string) ServerAzureADAdministratorsClient {
	return original.NewServerAzureADAdministratorsClient(subscriptionID)
}
func NewServerAzureADAdministratorsClientWithBaseURI(baseURI string, subscriptionID string) ServerAzureADAdministratorsClient {
	return original.NewServerAzureADAdministratorsClientWithBaseURI(baseURI, subscriptionID)
}
func NewServerVulnerabilityAssessmentListResultIterator(page ServerVulnerabilityAssessmentListResultPage) ServerVulnerabilityAssessmentListResultIterator {
	return original.NewServerVulnerabilityAssessmentListResultIterator(page)
}
func NewServerVulnerabilityAssessmentListResultPage(cur ServerVulnerabilityAssessmentListResult, getNextPage func(context.Context, ServerVulnerabilityAssessmentListResult) (ServerVulnerabilityAssessmentListResult, error)) ServerVulnerabilityAssessmentListResultPage {
	return original.NewServerVulnerabilityAssessmentListResultPage(cur, getNextPage)
}
func NewServerVulnerabilityAssessmentsClient(subscriptionID string) ServerVulnerabilityAssessmentsClient {
	return original.NewServerVulnerabilityAssessmentsClient(subscriptionID)
}
func NewServerVulnerabilityAssessmentsClientWithBaseURI(baseURI string, subscriptionID string) ServerVulnerabilityAssessmentsClient {
	return original.NewServerVulnerabilityAssessmentsClientWithBaseURI(baseURI, subscriptionID)
}
func NewUsageListResultIterator(page UsageListResultPage) UsageListResultIterator {
	return original.NewUsageListResultIterator(page)
}
func NewUsageListResultPage(cur UsageListResult, getNextPage func(context.Context, UsageListResult) (UsageListResult, error)) UsageListResultPage {
	return original.NewUsageListResultPage(cur, getNextPage)
}
func NewUsagesClient(subscriptionID string) UsagesClient {
	return original.NewUsagesClient(subscriptionID)
}
func NewUsagesClientWithBaseURI(baseURI string, subscriptionID string) UsagesClient {
	return original.NewUsagesClientWithBaseURI(baseURI, subscriptionID)
}
func NewWithBaseURI(baseURI string, subscriptionID string) BaseClient {
	return original.NewWithBaseURI(baseURI, subscriptionID)
}
func PossibleCatalogCollationTypeValues() []CatalogCollationType {
	return original.PossibleCatalogCollationTypeValues()
}
func PossibleDatabaseStateValues() []DatabaseState {
	return original.PossibleDatabaseStateValues()
}
func PossibleIdentityTypeValues() []IdentityType {
	return original.PossibleIdentityTypeValues()
}
func PossibleInstancePoolLicenseTypeValues() []InstancePoolLicenseType {
	return original.PossibleInstancePoolLicenseTypeValues()
}
func PossibleManagedDatabaseCreateModeValues() []ManagedDatabaseCreateMode {
	return original.PossibleManagedDatabaseCreateModeValues()
}
func PossibleManagedDatabaseStatusValues() []ManagedDatabaseStatus {
	return original.PossibleManagedDatabaseStatusValues()
}
func PossibleManagedInstanceLicenseTypeValues() []ManagedInstanceLicenseType {
	return original.PossibleManagedInstanceLicenseTypeValues()
}
func PossibleManagedInstanceProxyOverrideValues() []ManagedInstanceProxyOverride {
	return original.PossibleManagedInstanceProxyOverrideValues()
}
func PossibleManagedServerCreateModeValues() []ManagedServerCreateMode {
	return original.PossibleManagedServerCreateModeValues()
}
func PossibleManagementOperationStateValues() []ManagementOperationState {
	return original.PossibleManagementOperationStateValues()
}
func PossibleReplicaTypeValues() []ReplicaType {
	return original.PossibleReplicaTypeValues()
}
func PossibleSecurityAlertPolicyStateValues() []SecurityAlertPolicyState {
	return original.PossibleSecurityAlertPolicyStateValues()
}
func PossibleSensitivityLabelRankValues() []SensitivityLabelRank {
	return original.PossibleSensitivityLabelRankValues()
}
func PossibleSensitivityLabelSourceValues() []SensitivityLabelSource {
	return original.PossibleSensitivityLabelSourceValues()
}
func PossibleStatusValues() []Status {
	return original.PossibleStatusValues()
}
func UserAgent() string {
	return original.UserAgent() + " profiles/preview"
}
func Version() string {
	return original.Version()
}
