//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package customerinsightsapi

import original "github.com/Azure/azure-sdk-for-go/services/customerinsights/mgmt/2017-04-26/customerinsights/customerinsightsapi"

type AuthorizationPoliciesClientAPI = original.AuthorizationPoliciesClientAPI
type ConnectorMappingsClientAPI = original.ConnectorMappingsClientAPI
type ConnectorsClientAPI = original.ConnectorsClientAPI
type HubsClientAPI = original.HubsClientAPI
type ImagesClientAPI = original.ImagesClientAPI
type InteractionsClientAPI = original.InteractionsClientAPI
type KpiClientAPI = original.KpiClientAPI
type LinksClientAPI = original.LinksClientAPI
type OperationsClientAPI = original.OperationsClientAPI
type PredictionsClientAPI = original.PredictionsClientAPI
type ProfilesClientAPI = original.ProfilesClientAPI
type RelationshipLinksClientAPI = original.RelationshipLinksClientAPI
type RelationshipsClientAPI = original.RelationshipsClientAPI
type RoleAssignmentsClientAPI = original.RoleAssignmentsClientAPI
type RolesClientAPI = original.RolesClientAPI
type ViewsClientAPI = original.ViewsClientAPI
type WidgetTypesClientAPI = original.WidgetTypesClientAPI
