package websearchapi

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.
//
// Code generated by Microsoft (R) AutoRest Code Generator.
// Changes may cause incorrect behavior and will be lost if the code is regenerated.

import (
	"context"
	"github.com/Azure/azure-sdk-for-go/services/cognitiveservices/v1.0/websearch"
)

// WebClientAPI contains the set of methods on the WebClient type.
type WebClientAPI interface {
	Search(ctx context.Context, query string, acceptLanguage string, pragma string, userAgent string, clientID string, clientIP string, location string, answerCount *int32, countryCode string, count *int32, freshness websearch.Freshness, market string, offset *int32, promote []websearch.AnswerType, responseFilter []websearch.AnswerType, safeSearch websearch.SafeSearch, setLang string, textDecorations *bool, textFormat websearch.TextFormat) (result websearch.SearchResponse, err error)
}

var _ WebClientAPI = (*websearch.WebClient)(nil)
