//go:build go1.9
// +build go1.9

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.

// This code was auto-generated by:
// github.com/Azure/azure-sdk-for-go/eng/tools/profileBuilder

package runtimeapi

import original "github.com/Azure/azure-sdk-for-go/services/cognitiveservices/v3.0/luis/runtime/runtimeapi"

type PredictionClientAPI = original.PredictionClientAPI
